@@ -175,6 +175,7 @@ class MidiTracer;
 class NSM_Client;
 class LevelMeterHBox;
 class GUIObjectState;
+class BasicUI;
 
 namespace ARDOUR {
 	class ControlProtocolInfo;
@@ -292,6 +293,11 @@ public:
 	XMLNode* clock_mode_settings () const;
 	XMLNode* tearoff_settings (const char*) const;
 
+	void trigger_slot (int c, int r);
+	void trigger_cue_row (int r);
+	void stop_all_cues (bool immediately);
+	void stop_cues (int c, bool immediately);
+
 	void save_ardour_state ();
 	gboolean configure_handler (GdkEventConfigure* conf);
 
@@ -436,6 +442,7 @@ private:
 
 	Gtk::Menu*    _shared_popup_menu;
 
+	BasicUI*      _basic_ui;
 	void hide_tabbable (ArdourWidgets::Tabbable*);
 	void detach_tabbable (ArdourWidgets::Tabbable*);
 	void attach_tabbable (ArdourWidgets::Tabbable*);
