@@ -44,6 +44,7 @@
 #include "ardour/session.h"
 
 #include "control_protocol/control_protocol.h"
+#include "control_protocol/basic_ui.h"
 
 #include "gtkmm2ext/keyboard.h"
 #include "gtkmm2ext/utils.h"
@@ -103,6 +104,12 @@ ARDOUR_UI::set_session (Session *s)
 {
 	SessionHandlePtr::set_session (s);
 
+	if (_basic_ui) {
+		delete _basic_ui;
+	}
+
+	_basic_ui = new BasicUI (*s);
+
 	/* adjust sensitivity of menu bar options to reflect presence/absence
 	 * of session
 	 */
@@ -1039,6 +1046,7 @@ ARDOUR_UI::handle_locations_change (Location *)
 bool
 ARDOUR_UI::tabbed_window_state_event_handler (GdkEventWindowState* ev, void* object)
 {
+#ifndef __APPLE__
 	if (object == editor) {
 
 		if ((ev->changed_mask & GDK_WINDOW_STATE_FULLSCREEN) &&
@@ -1069,6 +1077,7 @@ ARDOUR_UI::tabbed_window_state_event_handler (GdkEventWindowState* ev, void* obj
 			}
 		}
 	}
+#endif
 
 	return false;
 }
