@@ -91,22 +91,21 @@ AutomationLine::AutomationLine (const string&                              name,
                                 const ParameterDescriptor&                 desc)
 	: trackview (tv)
 	, _name (name)
+	, _height (0)
+	, _view_index_offset (0)
 	, alist (al)
+	, _visible (Line)
+	, terminal_points_can_slide (true)
+	, update_pending (false)
+	, have_reset_timeout (false)
+	, no_draw (false)
+	, _is_boolean (false)
 	, _parent_group (parent)
 	, _offset (0)
 	, _maximum_time (timepos_t::max (al->time_domain()))
 	, _fill (false)
 	, _desc (desc)
 {
-	_visible = Line;
-
-	update_pending = false;
-	have_timeout = false;
-	no_draw = false;
-	_is_boolean = false;
-	terminal_points_can_slide = true;
-	_height = 0;
-
 	group = new ArdourCanvas::Container (&parent, ArdourCanvas::Duple(0, 1.5));
 	CANVAS_DEBUG_NAME (group, "region gain envelope group");
 
@@ -166,7 +165,7 @@ AutomationLine::update_visibility ()
 		   when automation points have been removed (the line will still follow the shape of the
 		   old points).
 		*/
-		if (control_points.size() >= 2) {
+		if (line_points.size() >= 2) {
 			line->show();
 		} else {
 			line->hide ();
@@ -210,6 +209,7 @@ AutomationLine::get_uses_gain_mapping () const
 		case BusSendLevel:
 		case EnvelopeAutomation:
 		case TrimAutomation:
+		case InsertReturnLevel:
 			return true;
 		default:
 			return false;
@@ -332,8 +332,8 @@ void
 AutomationLine::reset_line_coords (ControlPoint& cp)
 {
 	if (cp.view_index() < line_points.size()) {
-		line_points[cp.view_index()].x = cp.get_x ();
-		line_points[cp.view_index()].y = cp.get_y ();
+		line_points[cp.view_index() + _view_index_offset].x = cp.get_x ();
+		line_points[cp.view_index() + _view_index_offset].y = cp.get_y ();
 	}
 }
 
@@ -400,6 +400,7 @@ AutomationLine::string_to_fraction (string const & s) const
 		case BusSendLevel:
 		case EnvelopeAutomation:
 		case TrimAutomation:
+		case InsertReturnLevel:
 			if (s == "-inf") { /* translation */
 				v = 0;
 			} else {
@@ -409,8 +410,7 @@ AutomationLine::string_to_fraction (string const & s) const
 		default:
 			break;
 	}
-	model_to_view_coord_y (v);
-	return v;
+	return model_to_view_coord_y (v);
 }
 
 /** Start dragging a single point, possibly adding others if the supplied point is selected and there
@@ -552,7 +552,7 @@ AutomationLine::ContiguousControlPoints::move (double dx, double dvalue)
 		double view_y = 1.0 - (*i)->get_y() / line.height();
 		line.view_to_model_coord_y (view_y);
 		line.apply_delta (view_y, dvalue);
-		line.model_to_view_coord_y (view_y);
+		view_y = line.model_to_view_coord_y (view_y);
 		view_y = (1.0 - view_y) * line.height();
 
 		(*i)->move_to ((*i)->get_x() + dx, view_y, ControlPoint::Full);
@@ -780,7 +780,7 @@ AutomationLine::sync_model_with_view_point (ControlPoint& cp)
 	/* convert to absolute time on timeline */
 	const timepos_t absolute_time = model_time + get_origin();
 
-	/* now convert it back to match the view_x (RegioView pixel pos) */
+	/* now convert it back to match the view_x (RegionView pixel pos) */
 	const double model_x = trackview.editor().time_to_pixel_unrounded (absolute_time.earlier (_offset).earlier (get_origin ()));
 
 	if (view_x != model_x) {
@@ -809,7 +809,7 @@ AutomationLine::sync_model_with_view_point (ControlPoint& cp)
 	alist->modify (cp.model(), model_time, view_y);
 
 	/* convert back from model to view y for clamping position (for integer/boolean/etc) */
-	model_to_view_coord_y (view_y);
+	view_y = model_to_view_coord_y (view_y);
 	const double point_y = _height - (view_y * _height);
 	if (point_y != cp.get_y()) {
 		cp.move_to (cp.get_x(), point_y, ControlPoint::Full);
@@ -914,6 +914,7 @@ AutomationLine::get_selectables (timepos_t const & start, timepos_t const & end,
 
 		const timepos_t w = session_position ((*cp->model())->when);
 
+
 		if (w >= start && w <= end && cp->get_y() >= bot_track && cp->get_y() <= top_track) {
 			results.push_back (cp);
 		}
@@ -966,6 +967,16 @@ AutomationLine::list_changed ()
 	}
 }
 
+void
+AutomationLine::tempo_map_changed ()
+{
+	if (alist->time_domain() != Temporal::BeatTime) {
+		return;
+	}
+
+	reset ();
+}
+
 void
 AutomationLine::reset_callback (const Evoral::ControlList& events)
 {
@@ -979,6 +990,7 @@ AutomationLine::reset_callback (const Evoral::ControlList& events)
 		}
 		control_points.clear ();
 		line->hide();
+		line_points.clear ();
 		return;
 	}
 
@@ -991,15 +1003,25 @@ AutomationLine::reset_callback (const Evoral::ControlList& events)
 	line->hide ();
 	np = events.size();
 
-	Evoral::ControlList& e = const_cast<Evoral::ControlList&> (events);
+	Evoral::ControlList& e (const_cast<Evoral::ControlList&> (events));
+	AutomationList::iterator preceding (e.end());
+	AutomationList::iterator following (e.end());
 
 	for (AutomationList::iterator ai = e.begin(); ai != e.end(); ++ai, ++pi) {
 
-		double ty = (*ai)->value;
+		/* drop points outside our range */
 
-		/* convert from model coordinates to canonical view coordinates */
+		if (((*ai)->when < _offset)) {
+			preceding = ai;
+			continue;
+		}
 
-		timepos_t tx = model_to_view_coord (**ai, ty);
+		if ((*ai)->when >= _offset + _maximum_time) {
+			following = ai;
+			break;
+		}
+
+		double ty = model_to_view_coord_y ((*ai)->value);
 
 		if (isnan_local (ty)) {
 			warning << string_compose (_("Ignoring illegal points on AutomationLine \"%1\""),
@@ -1007,24 +1029,37 @@ AutomationLine::reset_callback (const Evoral::ControlList& events)
 			continue;
 		}
 
-		if (tx >= timepos_t::max (tx.time_domain()) || tx.is_negative () || tx >= _maximum_time) {
-			continue;
-		}
-
-		/* convert x-coordinate to a canvas unit coordinate (this takes
-		 * zoom and scroll into account).
-		 */
-
-		double px = trackview.editor().time_to_pixel_unrounded (tx);
-
 		/* convert from canonical view height (0..1.0) to actual
 		 * height coordinates (using X11's top-left rooted system)
 		 */
 
 		ty = _height - (ty * _height);
 
-		add_visible_control_point (vp, pi, px, ty, ai, np);
+		/* tx is currently the distance of this point from
+		 * _offset, which may be either:
+		 *
+		 * a) zero, for an automation line not connected to a
+		 * region
+		 *
+		 * b) some non-zero value, corresponding to the start
+		 * of the region within its source(s). Remember that
+		 * this start is an offset within the source, not a
+		 * position on the timeline.
+		 *
+		 * We need to convert tx to a global position, and to
+		 * do that we need to measure the distance from the
+		 * result of get_origin(), which tells ut the timeline
+		 * position of _offset
+		 */
 
+		timecnt_t tx = model_to_view_coord_x ((*ai)->when);
+
+		/* convert x-coordinate to a canvas unit coordinate (this takes
+		 * zoom and scroll into account).
+		 */
+
+		double px = trackview.editor().duration_to_pixels_unrounded (tx);
+		add_visible_control_point (vp, pi, px, ty, ai, np);
 		vp++;
 	}
 
@@ -1040,23 +1075,64 @@ AutomationLine::reset_callback (const Evoral::ControlList& events)
 		control_points.back()->set_can_slide(false);
 	}
 
-	if (vp > 1) {
+	if (vp) {
 
 		/* reset the line coordinates given to the CanvasLine */
 
-		while (line_points.size() < vp) {
-			line_points.push_back (ArdourCanvas::Duple (0,0));
+		/* 2 extra in case we need hidden points for line start and end */
+
+		line_points.resize (vp + 2, ArdourCanvas::Duple (0, 0));
+
+		ArdourCanvas::Points::size_type n = 0;
+
+		/* potentially insert front hidden (line) point to make the line draw from
+		 * zero to the first actual point
+		 */
+
+		_view_index_offset = 0;
+
+		if (control_points[0]->get_x() != 0 && preceding != e.end()) {
+			double ty = model_to_view_coord_y (e.unlocked_eval (_offset));
+
+			if (isnan_local (ty)) {
+				warning << string_compose (_("Ignoring illegal points on AutomationLine \"%1\""), _name) << endmsg;
+
+
+			} else {
+				line_points[n].y = _height - (ty * _height);
+				line_points[n].x = 0;
+				_view_index_offset = 1;
+				++n;
+			}
 		}
 
-		while (line_points.size() > vp) {
-			line_points.pop_back ();
+		for (auto const & cp : control_points) {
+			line_points[n].x = cp->get_x();
+			line_points[n].y = cp->get_y();
+			++n;
 		}
 
-		for (uint32_t n = 0; n < vp; ++n) {
-			line_points[n].x = control_points[n]->get_x();
-			line_points[n].y = control_points[n]->get_y();
+		/* potentially insert final hidden (line) point to make the line draw
+		 * from the last point to the very end
+		 */
+
+		double px = trackview.editor().duration_to_pixels_unrounded (model_to_view_coord_x (_offset + _maximum_time));
+
+		if (control_points[control_points.size() - 1]->get_x() != px && following != e.end()) {
+			double ty = model_to_view_coord_y (e.unlocked_eval (_offset + _maximum_time));
+
+			if (isnan_local (ty)) {
+				warning << string_compose (_("Ignoring illegal points on AutomationLine \"%1\""), _name) << endmsg;
+
+
+			} else {
+				line_points[n].y = _height - (ty * _height);
+				line_points[n].x = px;
+				++n;
+			}
 		}
 
+		line_points.resize (n);
 		line->set_steps (line_points, is_stepped());
 
 		update_visibility ();
@@ -1070,7 +1146,7 @@ AutomationLine::reset ()
 {
 	DEBUG_TRACE (DEBUG::Automation, "\t\tLINE RESET\n");
 	update_pending = false;
-	have_timeout = false;
+	have_reset_timeout = false;
 
 	if (no_draw) {
 		return;
@@ -1095,10 +1171,10 @@ AutomationLine::queue_reset ()
 	if (trackview.editor().session()->transport_rolling() && alist->automation_write()) {
 		/* automation write pass ... defer to a timeout */
 		/* redraw in 1/4 second */
-		if (!have_timeout) {
+		if (!have_reset_timeout) {
 			DEBUG_TRACE (DEBUG::Automation, "\tqueue timeout\n");
 			Glib::signal_timeout().connect (sigc::bind_return (sigc::mem_fun (*this, &AutomationLine::reset), false), 250);
-			have_timeout = true;
+			have_reset_timeout = true;
 		} else {
 			DEBUG_TRACE (DEBUG::Automation, "\ttimeout already queued, change ignored\n");
 		}
@@ -1227,8 +1303,8 @@ AutomationLine::apply_delta (double& val, double delta) const
 	val = _desc.apply_delta (val, delta);
 }
 
-void
-AutomationLine::model_to_view_coord_y (double& y) const
+double
+AutomationLine::model_to_view_coord_y (double y) const
 {
 	if (alist->default_interpolation () != alist->interpolation()) {
 		switch (alist->interpolation()) {
@@ -1237,8 +1313,7 @@ AutomationLine::model_to_view_coord_y (double& y) const
 				assert (alist->default_interpolation () == AutomationList::Linear);
 				break;
 			case AutomationList::Linear:
-				y = (y - _desc.lower) / (_desc.upper - _desc.lower);
-				return;
+				return (y - _desc.lower) / (_desc.upper - _desc.lower);
 			default:
 				/* types that default to linear, can't be use
 				 * Logarithmic or Exponential interpolation.
@@ -1248,15 +1323,22 @@ AutomationLine::model_to_view_coord_y (double& y) const
 				break;
 		}
 	}
-	y = _desc.to_interface (y);
+	return _desc.to_interface (y);
 }
 
-timepos_t
-AutomationLine::model_to_view_coord (Evoral::ControlEvent const & ev, double& y) const
+timecnt_t
+AutomationLine::model_to_view_coord_x (timepos_t const & when) const
 {
-	Temporal::timepos_t w (ev.when);
-	model_to_view_coord_y (y);
-	return (w).earlier (_offset);
+	/* @param when is a distance (with implicit origin) from the start of the
+	 * source. So we subtract the offset (from the region if this is
+	 * related to a region; zero otherwise) to get the distance (again,
+	 * implicit origin) from the start of the line.
+	 *
+	 * Then we construct a timecnt_t from this duration, and the origin of
+	 * the line on the timeline.
+	 */
+
+	return timecnt_t (when.earlier (_offset), get_origin());
 }
 
 /** Called when our list has announced that its interpolation style has changed */
@@ -1372,10 +1454,6 @@ AutomationLine::session_position (timepos_t const & when) const
 void
 AutomationLine::set_offset (timepos_t const & off)
 {
-	if (_offset == off) {
-		return;
-	}
-
 	_offset = off;
 	reset ();
 }
