@@ -114,6 +114,7 @@ public:
 	void set_height (guint32);
 
 	bool get_uses_gain_mapping () const;
+	void tempo_map_changed ();
 
 	TimeAxisView& trackview;
 
@@ -126,9 +127,11 @@ public:
 	std::string fraction_to_string (double) const;
 	std::string delta_to_string (double) const;
 	double string_to_fraction (std::string const &) const;
+
 	void   view_to_model_coord_y (double &) const;
-	Temporal::timepos_t model_to_view_coord (Evoral::ControlEvent const &, double& y) const;
-	void   model_to_view_coord_y (double &) const;
+
+	double              model_to_view_coord_y (double) const;
+	Temporal::timecnt_t model_to_view_coord_x (Temporal::timepos_t const &) const;
 
 	double compute_delta (double from, double to) const;
 	void   apply_delta (double& val, double delta) const;
@@ -168,14 +171,14 @@ protected:
 	std::string    _name;
 	guint32        _height;
 	uint32_t       _line_color;
-
+	uint32_t       _view_index_offset;
 	boost::shared_ptr<ARDOUR::AutomationList> alist;
 
 	VisibleAspects _visible;
 
 	bool    terminal_points_can_slide;
 	bool    update_pending;
-	bool    have_timeout;
+	bool    have_reset_timeout;
 	bool    no_draw;
 	bool    _is_boolean;
 	/** true if we did a push at any point during the current drag */
