@@ -603,6 +603,7 @@ public:
 	void edit_tempo_section (Temporal::TempoPoint&);
 	void edit_meter_section (Temporal::MeterPoint&);
 	void mouse_add_bbt_marker_event (Temporal::timepos_t where);
+	void add_bbt_marker_at_playhead_cursor ();
 
 	void edit_bbt (Temporal::MusicTimePoint&);
 
@@ -1458,6 +1459,7 @@ private:
 	                     boost::shared_ptr<ARDOUR::Track>&     track,
 	                     std::string const&                    pgroup_id,
 	                     bool                                  replace,
+	                     bool                                  with_markers,
 	                     boost::shared_ptr<ARDOUR::PluginInfo> instrument = boost::shared_ptr<ARDOUR::PluginInfo>());
 
 	int embed_sndfiles (std::vector<std::string>              paths,
@@ -1540,7 +1542,6 @@ private:
 	void import_audio (bool as_tracks);
 	void do_import (std::vector<std::string> paths, bool split, bool as_tracks);
 	void import_smf_tempo_map (Evoral::SMF const &, Temporal::timepos_t const & pos);
-	void import_smf_markers (Evoral::SMF &, Temporal::timepos_t const & pos);
 	void move_to_start ();
 	void move_to_end ();
 	void center_playhead ();
@@ -1718,13 +1719,7 @@ private:
 	bool canvas_note_event (GdkEvent* event, ArdourCanvas::Item*);
 
 	bool canvas_ruler_event (GdkEvent* event, ArdourCanvas::Item*, ItemType);
-	bool canvas_tempo_bar_event (GdkEvent* event, ArdourCanvas::Item*);
-	bool canvas_meter_bar_event (GdkEvent* event, ArdourCanvas::Item*);
-	bool canvas_marker_bar_event (GdkEvent* event, ArdourCanvas::Item*);
-	bool canvas_range_marker_bar_event (GdkEvent* event, ArdourCanvas::Item*);
-	bool canvas_transport_marker_bar_event (GdkEvent* event, ArdourCanvas::Item*);
-	bool canvas_cd_marker_bar_event (GdkEvent* event, ArdourCanvas::Item*);
-	bool canvas_cue_marker_bar_event (GdkEvent* event, ArdourCanvas::Item*);
+	bool canvas_ruler_bar_event (GdkEvent* event, ArdourCanvas::Item*, ItemType, std::string const&);
 
 	bool canvas_videotl_bar_event (GdkEvent* event, ArdourCanvas::Item*);
 	void update_video_timeline (bool flush = false);
