@@ -333,29 +333,6 @@ Editor::import_smf_tempo_map (Evoral::SMF const & smf, timepos_t const & pos)
 	tmc.use_new_map (new_map);
 }
 
-void
-Editor::import_smf_markers (Evoral::SMF & smf, timepos_t const & pos)
-{
-	if (!_session) {
-		return;
-	}
-
-	smf.load_markers ();
-
-	Evoral::SMF::Markers const & markers = smf.markers();
-
-	if (markers.empty()) {
-		return;
-	}
-
-	for (Evoral::SMF::Markers::const_iterator m = markers.begin(); m != markers.end(); ++m) {
-		Beats beats = Beats::from_double (m->time_pulses / (double) smf.ppqn());
-		Location* loc = new Location (*_session, timepos_t (beats), timepos_t (Temporal::BeatTime), m->text, Location::IsMark);
-		_session->locations()->add (loc);
-	}
-
-}
-
 void
 Editor::do_import (vector<string>           paths,
                    ImportDisposition        disposition,
@@ -383,7 +360,7 @@ Editor::do_import (vector<string>           paths,
 	   in the wrong position.
 	*/
 
-	if (with_markers || (smf_tempo_disposition == SMFTempoUse)) {
+	if (smf_tempo_disposition == SMFTempoUse) {
 
 		bool tempo_map_done = false;
 
@@ -405,11 +382,6 @@ Editor::do_import (vector<string>           paths,
 				}
 			}
 
-			if (with_markers) {
-
-				import_smf_markers (smf, pos);
-			}
-
 			smf.close ();
 		}
 	}
@@ -439,7 +411,7 @@ Editor::do_import (vector<string>           paths,
 
 		if (!cancel) {
 			ipw.show ();
-			import_sndfiles (paths, disposition, mode, quality, pos, 1, 1, track, pgroup_id, false, instrument);
+			import_sndfiles (paths, disposition, mode, quality, pos, 1, 1, track, pgroup_id, false, with_markers, instrument);
 			import_status.clear();
 		}
 
@@ -485,7 +457,7 @@ Editor::do_import (vector<string>           paths,
 					track = get_nth_selected_audio_track (nth++);
 				}
 
-				import_sndfiles (to_import, disposition, mode, quality, pos, 1, -1, track, pgroup_id, replace, instrument);
+				import_sndfiles (to_import, disposition, mode, quality, pos, 1, -1, track, pgroup_id, replace, with_markers, instrument);
 				import_status.clear();
 				break;
 
@@ -494,7 +466,7 @@ Editor::do_import (vector<string>           paths,
 				to_import.clear ();
 				to_import.push_back (*a);
 
-				import_sndfiles (to_import, disposition, mode, quality, pos, -1, -1, track, pgroup_id, replace, instrument);
+				import_sndfiles (to_import, disposition, mode, quality, pos, -1, -1, track, pgroup_id, replace, with_markers, instrument);
 				import_status.clear();
 				break;
 
@@ -503,7 +475,7 @@ Editor::do_import (vector<string>           paths,
 				to_import.clear ();
 				to_import.push_back (*a);
 
-				import_sndfiles (to_import, disposition, mode, quality, pos, 1, 1, track, pgroup_id, replace, instrument);
+				import_sndfiles (to_import, disposition, mode, quality, pos, 1, 1, track, pgroup_id, replace, with_markers, instrument);
 				import_status.clear();
 				break;
 
@@ -611,6 +583,7 @@ Editor::import_sndfiles (vector<string>            paths,
                          boost::shared_ptr<Track>& track,
                          std::string const&        pgroup_id,
                          bool                      replace,
+                         bool                      with_markers,
                          ARDOUR::PluginInfoPtr     instrument)
 {
 	/* skip periodic saves while importing */
@@ -622,6 +595,7 @@ Editor::import_sndfiles (vector<string>            paths,
 	import_status.quality = quality;
 	import_status.replace_existing_source = replace;
 	import_status.split_midi_channels = (disposition == Editing::ImportDistinctChannels);
+	import_status.import_markers = with_markers;
 
 	import_status.mode = mode;
 	import_status.pos = pos;
@@ -723,7 +697,7 @@ Editor::embed_sndfiles (vector<string>            paths,
 				choices.push_back (_("Embed all without questions"));
 
 				ArdourWidgets::Choice rate_choice (
-					_("Sample rate"),
+					_("Sample Rate"),
 					string_compose (_("%1\nThis audiofile's sample rate doesn't match the session sample rate!"),
 							short_path (path, 40)),
 					choices, false
@@ -749,7 +723,7 @@ Editor::embed_sndfiles (vector<string>            paths,
 				choices.push_back (_("Embed it anyway"));
 
 				ArdourWidgets::Choice rate_choice (
-					_("Sample rate"),
+					_("Sample Rate"),
 					string_compose (_("%1\nThis audiofile's sample rate doesn't match the session sample rate!"), path),
 					choices, false
 					);
@@ -1170,9 +1144,8 @@ Editor::finish_bringing_in_material (boost::shared_ptr<Region> region,
 			}
 		} else {
 			boost::shared_ptr<Playlist> playlist = existing_track->playlist();
-			boost::shared_ptr<Region> copy (RegionFactory::create (region, true));
 			playlist->clear_changes ();
-			playlist->add_region (copy, pos);
+			playlist->add_region (region, pos);
 			_session->add_command (new StatefulDiffCommand (playlist));
 		}
 		break;
