@@ -58,6 +58,7 @@
 #include "editor_cursors.h"
 #include "mouse_cursors.h"
 #include "note_base.h"
+#include "region_peak_cursor.h"
 #include "ui_config.h"
 #include "verbose_cursor.h"
 
@@ -105,6 +106,7 @@ Editor::initialize_canvas ()
 	_track_canvas->add_scroller (*cg);
 
 	_verbose_cursor = new VerboseCursor (this);
+	_region_peak_cursor = new RegionPeakCursor (get_noscroll_group ());
 
 	/*a group to hold global rects like punch/loop indicators */
 	global_rect_group = new ArdourCanvas::Container (hv_scroll_group);
@@ -158,29 +160,42 @@ Editor::initialize_canvas ()
 	meter_group = new ArdourCanvas::Container (_time_markers_group, ArdourCanvas::Duple (0.0, (timebar_height * 5.0) + 1.0));
 	CANVAS_DEBUG_NAME (meter_group, "meter group");
 
-	meter_bar = new ArdourCanvas::Rectangle (meter_group, ArdourCanvas::Rect (0.0, 0.0, ArdourCanvas::COORD_MAX, timebar_height));
+	float timebar_thickness = timebar_height; //was 4
+	float timebar_top = (timebar_height - timebar_thickness)/2;
+	float timebar_btm = timebar_height - timebar_top;
+
+	meter_bar = new ArdourCanvas::Rectangle (meter_group, ArdourCanvas::Rect (0.0, 0., ArdourCanvas::COORD_MAX, timebar_height));
 	CANVAS_DEBUG_NAME (meter_bar, "meter Bar");
-	meter_bar->set_outline_what (ArdourCanvas::Rectangle::BOTTOM);
+	meter_bar->set_outline(false);
 
 	tempo_bar = new ArdourCanvas::Rectangle (tempo_group, ArdourCanvas::Rect (0.0, 0.0, ArdourCanvas::COORD_MAX, timebar_height));
 	CANVAS_DEBUG_NAME (tempo_bar, "Tempo  Bar");
-	tempo_bar->set_outline_what (ArdourCanvas::Rectangle::BOTTOM);
+	tempo_bar->set_fill(true);
+	tempo_bar->set_outline(false);
+	tempo_bar->set_outline_what(ArdourCanvas::Rectangle::BOTTOM);
 
-	range_marker_bar = new ArdourCanvas::Rectangle (range_marker_group, ArdourCanvas::Rect (0.0, 0.0, ArdourCanvas::COORD_MAX, timebar_height));
+	range_marker_bar = new ArdourCanvas::Rectangle (range_marker_group, ArdourCanvas::Rect (0.0, timebar_top, ArdourCanvas::COORD_MAX, timebar_btm));
 	CANVAS_DEBUG_NAME (range_marker_bar, "Range Marker Bar");
-	range_marker_bar->set_outline_what (ArdourCanvas::Rectangle::BOTTOM);
 
-	transport_marker_bar = new ArdourCanvas::Rectangle (transport_marker_group, ArdourCanvas::Rect (0.0, 0.0, ArdourCanvas::COORD_MAX, timebar_height));
+	transport_marker_bar = new ArdourCanvas::Rectangle (transport_marker_group, ArdourCanvas::Rect (0.0, timebar_top, ArdourCanvas::COORD_MAX, timebar_btm));
 	CANVAS_DEBUG_NAME (transport_marker_bar, "transport Marker Bar");
-	transport_marker_bar->set_outline_what (ArdourCanvas::Rectangle::BOTTOM);
 
-	marker_bar = new ArdourCanvas::Rectangle (marker_group, ArdourCanvas::Rect (0.0, 0.0, ArdourCanvas::COORD_MAX, timebar_height));
+	marker_bar = new ArdourCanvas::Rectangle (marker_group, ArdourCanvas::Rect (0.0, timebar_top, ArdourCanvas::COORD_MAX, timebar_btm));
 	CANVAS_DEBUG_NAME (marker_bar, "Marker Bar");
-	marker_bar->set_outline_what (ArdourCanvas::Rectangle::BOTTOM);
 
-	cd_marker_bar = new ArdourCanvas::Rectangle (cd_marker_group, ArdourCanvas::Rect (0.0, 0.0, ArdourCanvas::COORD_MAX, timebar_height));
+	cd_marker_bar = new ArdourCanvas::Rectangle (cd_marker_group, ArdourCanvas::Rect (0.0, timebar_top, ArdourCanvas::COORD_MAX, timebar_btm));
 	CANVAS_DEBUG_NAME (cd_marker_bar, "CD Marker Bar");
-	cd_marker_bar->set_outline_what (ArdourCanvas::Rectangle::BOTTOM);
+
+	cue_marker_group = new ArdourCanvas::Container (_time_markers_group, ArdourCanvas::Duple (0.0, 0.0));
+	cue_marker_bar = new ArdourCanvas::Rectangle (cue_marker_group, ArdourCanvas::Rect (0.0, timebar_top, ArdourCanvas::COORD_MAX, timebar_btm));
+	CANVAS_DEBUG_NAME (cue_marker_bar, "Cue Marker Bar");
+
+	ruler_separator = new ArdourCanvas::Line(_time_markers_group);
+	CANVAS_DEBUG_NAME (ruler_separator, "separator between ruler and main canvas");
+	ruler_separator->set (ArdourCanvas::Duple(0.0, 0.0), ArdourCanvas::Duple(ArdourCanvas::COORD_MAX, 0.0));
+	ruler_separator->set_outline_color(Gtkmm2ext::rgba_to_color (0, 0, 0, 1.0));
+	ruler_separator->set_outline_width(1.0);
+	ruler_separator->show();
 
 	ARDOUR_UI::instance()->video_timeline = new VideoTimeLine(this, videotl_group, (timebar_height * videotl_bar_height));
 
@@ -189,6 +204,11 @@ Editor::initialize_canvas ()
 	cd_marker_bar_drag_rect->set_outline (false);
 	cd_marker_bar_drag_rect->hide ();
 
+	cue_marker_bar_drag_rect = new ArdourCanvas::Rectangle (cue_marker_group, ArdourCanvas::Rect (0.0, 0.0, 100, timebar_height));
+	CANVAS_DEBUG_NAME (cd_marker_bar_drag_rect, "cd marker drag");
+	cue_marker_bar_drag_rect->set_outline (false);
+	cue_marker_bar_drag_rect->hide ();
+
 	range_bar_drag_rect = new ArdourCanvas::Rectangle (range_marker_group, ArdourCanvas::Rect (0.0, 0.0, 100, timebar_height));
 	CANVAS_DEBUG_NAME (range_bar_drag_rect, "range drag");
 	range_bar_drag_rect->set_outline (false);
@@ -213,17 +233,18 @@ Editor::initialize_canvas ()
 	transport_punchout_line->set_y1 (ArdourCanvas::COORD_MAX);
 	transport_punchout_line->hide();
 
-	tempo_bar->Event.connect (sigc::bind (sigc::mem_fun (*this, &Editor::canvas_tempo_bar_event), tempo_bar));
-	meter_bar->Event.connect (sigc::bind (sigc::mem_fun (*this, &Editor::canvas_meter_bar_event), meter_bar));
-	marker_bar->Event.connect (sigc::bind (sigc::mem_fun (*this, &Editor::canvas_marker_bar_event), marker_bar));
-	cd_marker_bar->Event.connect (sigc::bind (sigc::mem_fun (*this, &Editor::canvas_cd_marker_bar_event), cd_marker_bar));
+	tempo_bar->Event.connect (sigc::bind (sigc::mem_fun (*this, &Editor::canvas_ruler_bar_event), tempo_bar, TempoBarItem, "tempo bar"));
+	meter_bar->Event.connect (sigc::bind (sigc::mem_fun (*this, &Editor::canvas_ruler_bar_event), meter_bar, MeterBarItem, "meter bar"));
+	marker_bar->Event.connect (sigc::bind (sigc::mem_fun (*this, &Editor::canvas_ruler_bar_event), marker_bar, MarkerBarItem, "marker bar"));
+	cd_marker_bar->Event.connect (sigc::bind (sigc::mem_fun (*this, &Editor::canvas_ruler_bar_event), cd_marker_bar, CdMarkerBarItem, "cd marker bar"));
+	cue_marker_bar->Event.connect (sigc::bind (sigc::mem_fun (*this, &Editor::canvas_ruler_bar_event), cue_marker_bar, CueMarkerBarItem, "cd marker bar"));
 	videotl_group->Event.connect (sigc::bind (sigc::mem_fun (*this, &Editor::canvas_videotl_bar_event), videotl_group));
-	range_marker_bar->Event.connect (sigc::bind (sigc::mem_fun (*this, &Editor::canvas_range_marker_bar_event), range_marker_bar));
-	transport_marker_bar->Event.connect (sigc::bind (sigc::mem_fun (*this, &Editor::canvas_transport_marker_bar_event), transport_marker_bar));
+	range_marker_bar->Event.connect (sigc::bind (sigc::mem_fun (*this, &Editor::canvas_ruler_bar_event), range_marker_bar, RangeMarkerBarItem, "range marker bar"));
+	transport_marker_bar->Event.connect (sigc::bind (sigc::mem_fun (*this, &Editor::canvas_ruler_bar_event), transport_marker_bar, TransportMarkerBarItem, "transport marker bar"));
 
-	playhead_cursor = new EditorCursor (*this, &Editor::canvas_playhead_cursor_event);
+	_playhead_cursor = new EditorCursor (*this, &Editor::canvas_playhead_cursor_event, X_("playhead"));
 
-	snapped_cursor = new EditorCursor (*this);
+	_snapped_cursor = new EditorCursor (*this, X_("snapped"));
 
 	_canvas_drop_zone = new ArdourCanvas::Rectangle (hv_scroll_group, ArdourCanvas::Rect (0.0, 0.0, ArdourCanvas::COORD_MAX, 0.0));
 	/* this thing is transparent */
@@ -247,7 +268,7 @@ Editor::initialize_canvas ()
 	_track_canvas->add_events (Gdk::POINTER_MOTION_HINT_MASK | Gdk::SCROLL_MASK | Gdk::KEY_PRESS_MASK | Gdk::KEY_RELEASE_MASK);
 	_track_canvas->signal_leave_notify_event().connect (sigc::mem_fun(*this, &Editor::left_track_canvas), false);
 	_track_canvas->signal_enter_notify_event().connect (sigc::mem_fun(*this, &Editor::entered_track_canvas), false);
-	_track_canvas->set_flags (CAN_FOCUS);
+	_track_canvas->set_can_focus ();
 
 	_track_canvas->PreRender.connect (sigc::mem_fun(*this, &Editor::pre_render));
 
@@ -255,8 +276,7 @@ Editor::initialize_canvas ()
 
 	vector<TargetEntry> target_table;
 
-	target_table.push_back (TargetEntry ("regions")); // DnD from the region list will generate this target
-	target_table.push_back (TargetEntry ("sources")); // DnD from the source list will generate this target
+	target_table.push_back (TargetEntry ("x-ardour/region.pbdid", TARGET_SAME_APP));
 	target_table.push_back (TargetEntry ("text/uri-list"));
 	target_table.push_back (TargetEntry ("text/plain"));
 	target_table.push_back (TargetEntry ("application/x-rootwin-drop"));
@@ -294,10 +314,6 @@ Editor::track_canvas_viewport_size_allocated ()
 
 	if (height_changed) {
 
-		for (LocationMarkerMap::iterator i = location_markers.begin(); i != location_markers.end(); ++i) {
-			i->second->canvas_height_set (_visible_canvas_height);
-		}
-
 		vertical_adjustment.set_page_size (_visible_canvas_height);
 		if ((vertical_adjustment.get_value() + _visible_canvas_height) >= vertical_adjustment.get_upper()) {
 			/*
@@ -311,6 +327,7 @@ Editor::track_canvas_viewport_size_allocated ()
 	}
 
 	update_fixed_rulers();
+	update_tempo_based_rulers ();
 	redisplay_grid (false);
 	_summary->set_overlays_dirty ();
 }
@@ -321,11 +338,11 @@ Editor::reset_controls_layout_width ()
 	GtkRequisition req = { 0, 0 };
 	gint w;
 
-	edit_controls_vbox.size_request (req);
+	req = edit_controls_vbox.size_request ();
 	w = req.width;
 
-	if (_group_tabs->is_visible()) {
-		_group_tabs->size_request (req);
+	if (_group_tabs->get_visible()) {
+		req = _group_tabs->size_request ();
 		w += req.width;
 	}
 
@@ -381,26 +398,25 @@ Editor::track_canvas_drag_data_received (const RefPtr<Gdk::DragContext>& context
 	if (!ARDOUR_UI_UTILS::engine_is_running ()) {
 		return;
 	}
-	if (data.get_target() == X_("regions")) {
-		drop_regions (context, x, y, data, info, time, true);
-	} else if (data.get_target() == X_("sources")) {
-		drop_regions (context, x, y, data, info, time, false);
+	if (data.get_target() == "x-ardour/region.pbdid") {
+		drop_regions (context, x, y, data, info, time);
 	} else {
 		drop_paths (context, x, y, data, info, time);
 	}
 }
 
 bool
-Editor::idle_drop_paths (vector<string> paths, samplepos_t sample, double ypos, bool copy)
+Editor::idle_drop_paths (vector<string> paths, timepos_t pos, double ypos, bool copy)
 {
-	drop_paths_part_two (paths, sample, ypos, copy);
+	drop_paths_part_two (paths, pos, ypos, copy);
 	return false;
 }
 
 void
-Editor::drop_paths_part_two (const vector<string>& paths, samplepos_t sample, double ypos, bool copy)
+Editor::drop_paths_part_two (const vector<string>& paths, timepos_t const & p, double ypos, bool copy)
 {
 	RouteTimeAxisView* tv;
+	timepos_t pos (p);
 
 	/* MIDI files must always be imported, because we consider them
 	 * writable. So split paths into two vectors, and follow the import
@@ -418,20 +434,19 @@ Editor::drop_paths_part_two (const vector<string>& paths, samplepos_t sample, do
 		}
 	}
 
-
 	std::pair<TimeAxisView*, int> const tvp = trackview_by_y_position (ypos, false);
 	if (tvp.first == 0) {
 
 		/* drop onto canvas background: create new tracks */
 
-		InstrumentSelector is; // instantiation builds instrument-list and sets default.
-		do_import (midi_paths, Editing::ImportDistinctFiles, ImportAsTrack, SrcBest, SMFTrackName, SMFTempoIgnore, sample, is.selected_instrument());
+		InstrumentSelector is(InstrumentSelector::ForTrackDefault); // instantiation builds instrument-list and sets default.
+	        do_import (midi_paths, Editing::ImportDistinctFiles, ImportAsTrack, SrcBest, SMFTrackNumber, SMFTempoIgnore, pos, is.selected_instrument());
 
 		if (UIConfiguration::instance().get_only_copy_imported_files() || copy) {
 			do_import (audio_paths, Editing::ImportDistinctFiles, Editing::ImportAsTrack,
-			           SrcBest, SMFTrackName, SMFTempoIgnore, sample);
+			           SrcBest, SMFTrackName, SMFTempoIgnore, pos);
 		} else {
-			do_embed (audio_paths, Editing::ImportDistinctFiles, ImportAsTrack, sample);
+			do_embed (audio_paths, Editing::ImportDistinctFiles, ImportAsTrack, pos);
 		}
 
 	} else if ((tv = dynamic_cast<RouteTimeAxisView*> (tvp.first)) != 0) {
@@ -439,17 +454,14 @@ Editor::drop_paths_part_two (const vector<string>& paths, samplepos_t sample, do
 		/* check that its a track, not a bus */
 
 		if (tv->track()) {
-			/* select the track, then embed/import */
-			selection->set (tv);
-
 			do_import (midi_paths, Editing::ImportSerializeFiles, ImportToTrack,
-				   SrcBest, SMFTrackName, SMFTempoIgnore, sample);
+				   SrcBest, SMFTrackNumber, SMFTempoIgnore, pos, boost::shared_ptr<ARDOUR::PluginInfo>(), tv->track ());
 
 			if (UIConfiguration::instance().get_only_copy_imported_files() || copy) {
 				do_import (audio_paths, Editing::ImportSerializeFiles, Editing::ImportToTrack,
-					   SrcBest, SMFTrackName, SMFTempoIgnore, sample);
+					   SrcBest, SMFTrackName, SMFTempoIgnore, pos, boost::shared_ptr<PluginInfo>(), tv->track ());
 			} else {
-				do_embed (audio_paths, Editing::ImportSerializeFiles, ImportToTrack, sample);
+				do_embed (audio_paths, Editing::ImportSerializeFiles, ImportToTrack, pos, boost::shared_ptr<ARDOUR::PluginInfo>(), tv->track ());
 			}
 		}
 	}
@@ -465,16 +477,15 @@ Editor::drop_paths (const RefPtr<Gdk::DragContext>& context,
 	GdkEvent ev;
 	double cy;
 
-	if (convert_drop_to_paths (paths, context, x, y, data, info, time) == 0) {
+	if (_session && convert_drop_to_paths (paths, data)) {
 
-		/* D-n-D coordinates are window-relative, so convert to canvas coordinates
-		 */
+		/* D-n-D coordinates are window-relative, so convert to canvas coordinates */
 
 		ev.type = GDK_BUTTON_RELEASE;
 		ev.button.x = x;
 		ev.button.y = y;
 
-		MusicSample when (window_event_sample (&ev, 0, &cy), 0);
+		timepos_t when (window_event_sample (&ev, 0, &cy));
 		snap_to (when);
 
 		bool copy = ((context->get_actions() & (Gdk::ACTION_COPY | Gdk::ACTION_LINK | Gdk::ACTION_MOVE)) == Gdk::ACTION_COPY);
@@ -483,9 +494,9 @@ Editor::drop_paths (const RefPtr<Gdk::DragContext>& context,
 		   the main event loop with GTK/Quartz. Since import/embed wants
 		   to push up a progress dialog, defer all this till we go idle.
 		*/
-		Glib::signal_idle().connect (sigc::bind (sigc::mem_fun (*this, &Editor::idle_drop_paths), paths, when.sample, cy, copy));
+		Glib::signal_idle().connect (sigc::bind (sigc::mem_fun (*this, &Editor::idle_drop_paths), paths, when, cy, copy));
 #else
-		drop_paths_part_two (paths, when.sample, cy, copy);
+		drop_paths_part_two (paths, when, cy, copy);
 #endif
 	}
 
@@ -604,15 +615,15 @@ Editor::autoscroll_active () const
 	return autoscroll_connection.connected ();
 }
 
-std::pair <samplepos_t,samplepos_t>
+std::pair <timepos_t,timepos_t>
 Editor::session_gui_extents (bool use_extra) const
 {
 	if (!_session) {
-		return std::pair <samplepos_t,samplepos_t>(max_samplepos,0);
+		return std::make_pair (timepos_t::max (Temporal::AudioTime), timepos_t (Temporal::AudioTime));
 	}
 
-	samplecnt_t session_extent_start = _session->current_start_sample();
-	samplecnt_t session_extent_end = _session->current_end_sample();
+	timepos_t session_extent_start (_session->current_start_sample());
+	timepos_t session_extent_end (_session->current_end_sample());
 
 	/* calculate the extents of all regions in every playlist
 	 * NOTE: we should listen to playlists, and cache these values so we don't calculate them every time.
@@ -621,19 +632,20 @@ Editor::session_gui_extents (bool use_extra) const
 		boost::shared_ptr<RouteList> rl = _session->get_routes();
 		for (RouteList::iterator r = rl->begin(); r != rl->end(); ++r) {
 			boost::shared_ptr<Track> tr = boost::dynamic_pointer_cast<Track> (*r);
-			if (tr) {
-				boost::shared_ptr<Playlist> pl = tr->playlist();
-				if (pl && !pl->all_regions_empty()) {
-					pair<samplepos_t, samplepos_t> e;
-					e = pl->get_extent();
-					if (e.first < session_extent_start) {
-						session_extent_start = e.first;
-					}
-					if (e.second > session_extent_end) {
-						session_extent_end = e.second;
-					}
-				}
+
+			if (!tr) {
+				continue;
 			}
+			if (tr->presentation_info ().hidden ()) {
+				continue;
+			}
+			pair<timepos_t, timepos_t> e = tr->playlist()->get_extent ();
+			if (e.first == e.second) {
+				/* no regions present */
+				continue;
+			}
+			session_extent_start = std::min (session_extent_start, e.first);
+			session_extent_end   = std::max (session_extent_end, e.second);
 		}
 	}
 
@@ -641,21 +653,20 @@ Editor::session_gui_extents (bool use_extra) const
 
 	/* add additional time to the ui extents (user-defined in config) */
 	if (use_extra) {
-		samplecnt_t const extra = UIConfiguration::instance().get_extra_ui_extents_time() * 60 * _session->nominal_sample_rate();
-		session_extent_end += extra;
-		session_extent_start -= extra;
+		timecnt_t const extra ((samplepos_t) (UIConfiguration::instance().get_extra_ui_extents_time() * 60 * _session->nominal_sample_rate()));
+		session_extent_end += timepos_t (extra);
+		session_extent_start.shift_earlier (extra);
 	}
 
 	/* range-check */
-	if (session_extent_end > max_samplepos) {
-		session_extent_end = max_samplepos;
+	if (session_extent_end >= timepos_t::max (Temporal::AudioTime)) {
+		session_extent_end = timepos_t::max (Temporal::AudioTime);
 	}
-	if (session_extent_start < 0) {
-		session_extent_start = 0;
+	if (session_extent_start.is_negative()) {
+		session_extent_start = timepos_t (0);
 	}
 
-	std::pair <samplepos_t,samplepos_t> ret (session_extent_start, session_extent_end);
-	return ret;
+	return std::make_pair (session_extent_start, session_extent_end);
 }
 
 bool
@@ -950,6 +961,9 @@ Editor::ensure_time_axis_view_is_visible (TimeAxisView const & track, bool at_to
 		return;
 	}
 
+	/* apply any pending [height] changes */
+	(void) process_redisplay_track_views ();
+
 	/* compute visible area of trackview group, as offsets from top of
 	 * trackview group.
 	 */
@@ -993,6 +1007,7 @@ void
 Editor::tie_vertical_scrolling ()
 {
 	if (pending_visual_change.idle_handler_id < 0) {
+		_region_peak_cursor->hide ();
 		_summary->set_overlays_dirty ();
 	}
 }
@@ -1019,13 +1034,12 @@ Editor::color_handler()
 	bbt_ruler->set_fill_color (base);
 	bbt_ruler->set_outline_color (text);
 
-	playhead_cursor->set_color (UIConfiguration::instance().color ("play head"));
+	_playhead_cursor->set_color (UIConfiguration::instance().color ("play head"));
 
 	meter_bar->set_fill_color (UIConfiguration::instance().color_mod ("meter bar", "marker bar"));
 	meter_bar->set_outline_color (UIConfiguration::instance().color ("marker bar separator"));
 
 	tempo_bar->set_fill_color (UIConfiguration::instance().color_mod ("tempo bar", "marker bar"));
-	tempo_bar->set_outline_color (UIConfiguration::instance().color ("marker bar separator"));
 
 	marker_bar->set_fill_color (UIConfiguration::instance().color_mod ("marker bar", "marker bar"));
 	marker_bar->set_outline_color (UIConfiguration::instance().color ("marker bar separator"));
@@ -1033,6 +1047,9 @@ Editor::color_handler()
 	cd_marker_bar->set_fill_color (UIConfiguration::instance().color_mod ("cd marker bar", "marker bar"));
 	cd_marker_bar->set_outline_color (UIConfiguration::instance().color ("marker bar separator"));
 
+	cue_marker_bar->set_fill_color (UIConfiguration::instance().color_mod ("cd marker bar", "marker bar"));
+	cue_marker_bar->set_outline_color (UIConfiguration::instance().color ("marker bar separator"));
+
 	range_marker_bar->set_fill_color (UIConfiguration::instance().color_mod ("range marker bar", "marker bar"));
 	range_marker_bar->set_outline_color (UIConfiguration::instance().color ("marker bar separator"));
 
@@ -1314,7 +1331,7 @@ Editor::which_canvas_cursor(ItemType type) const
 		/* We don't choose a cursor for these items on top of a region view,
 		   because this would push a new context on the enter stack which
 		   means switching the region context for things like smart mode
-		   won't actualy change the cursor. */
+		   won't actually change the cursor. */
 		// case WaveItem:
 		case StreamItem:
 		case AutomationTrackItem:
@@ -1435,6 +1452,7 @@ Editor::which_canvas_cursor(ItemType type) const
 
 		/* These items use the grabber cursor at all times */
 	case MeterMarkerItem:
+	case BBTMarkerItem:
 	case TempoMarkerItem:
 	case MeterBarItem:
 	case TempoBarItem:
@@ -1442,6 +1460,7 @@ Editor::which_canvas_cursor(ItemType type) const
 	case MarkerBarItem:
 	case RangeMarkerBarItem:
 	case CdMarkerBarItem:
+	case CueMarkerBarItem:
 	case VideoBarItem:
 	case TransportMarkerBarItem:
 	case DropZoneItem:
