@@ -51,6 +51,7 @@
 #include "actions.h"
 #include "editor_drag.h"
 #include "region_view.h"
+#include "tempo_map_change.h"
 
 #include "pbd/i18n.h"
 
@@ -741,8 +742,6 @@ Editor::mouse_add_new_marker (timepos_t where, Location::Flags extra_flags, int3
 	string namebase;
 	Location::Flags flags = Location::Flags (extra_flags|Location::IsMark);
 
-	cerr << "adding new marker @ " << where << endl;
-
 	if (_session) {
 
 		if (flags & Location::IsCueMarker) {
@@ -1073,9 +1072,9 @@ Editor::build_marker_menu (Location* loc)
 		items.push_back (SeparatorElem());
 	}
 
-	items.push_back (MenuElem (_("Locate to Here"), sigc::mem_fun(*this, &Editor::marker_menu_set_playhead)));
-	items.push_back (MenuElem (_("Play from Here"), sigc::mem_fun(*this, &Editor::marker_menu_play_from)));
-	items.push_back (MenuElem (_("Move Mark to Playhead"), sigc::mem_fun(*this, &Editor::marker_menu_set_from_playhead)));
+	items.push_back (MenuElem (_("Move Playhead to Marker"), sigc::mem_fun(*this, &Editor::marker_menu_set_playhead)));
+	items.push_back (MenuElem (_("Play from Marker"), sigc::mem_fun(*this, &Editor::marker_menu_play_from)));
+	items.push_back (MenuElem (_("Move Marker to Playhead"), sigc::mem_fun(*this, &Editor::marker_menu_set_from_playhead)));
 
 	items.push_back (SeparatorElem());
 
@@ -1119,11 +1118,11 @@ Editor::build_range_marker_menu (Location* loc, bool loop_or_punch, bool session
 	range_marker_menu->set_name ("ArdourContextMenu");
 
 	items.push_back (MenuElem (_("Play Range"), sigc::mem_fun(*this, &Editor::marker_menu_play_range)));
-	items.push_back (MenuElem (_("Locate to Marker"), sigc::mem_fun(*this, &Editor::marker_menu_set_playhead)));
+	items.push_back (MenuElem (_("Move Playhead to Marker"), sigc::mem_fun(*this, &Editor::marker_menu_set_playhead)));
 	items.push_back (MenuElem (_("Play from Marker"), sigc::mem_fun(*this, &Editor::marker_menu_play_from)));
 	items.push_back (MenuElem (_("Loop Range"), sigc::mem_fun(*this, &Editor::marker_menu_loop_range)));
 
-	items.push_back (MenuElem (_("Set Marker from Playhead"), sigc::mem_fun(*this, &Editor::marker_menu_set_from_playhead)));
+	items.push_back (MenuElem (_("Move Marker to Playhead"), sigc::mem_fun(*this, &Editor::marker_menu_set_from_playhead)));
 	items.push_back (MenuElem (_("Set Range from Selection"), sigc::bind (sigc::mem_fun(*this, &Editor::marker_menu_set_from_selection), false)));
 
 	items.push_back (MenuElem (_("Zoom to Range"), sigc::mem_fun (*this, &Editor::marker_menu_zoom_to_range)));
@@ -1641,7 +1640,6 @@ Editor::marker_menu_remove ()
 	}
 }
 
-/* actually just resets the ts to constant using initial tempo */
 void
 Editor::toggle_tempo_type ()
 {
@@ -1650,23 +1648,14 @@ Editor::toggle_tempo_type ()
 	BBTMarker* bm;
 	dynamic_cast_marker_object (marker_menu_item->get_data ("marker"), &mm, &tm, &bm);
 
-	if (tm) {
+	if (!tm) {
+		return;
+	}
 
-		begin_reversible_command (_("set tempo to constant"));
-		TempoMap::WritableSharedPtr tmap (TempoMap::write_copy());
-
-		reassociate_metric_markers (tmap);
-		Temporal::TempoPoint const & tempo = tm->tempo();
-
-		XMLNode &before = tmap->get_state();
-
-		tmap->set_ramped (const_cast<Temporal::TempoPoint&>(tempo), !tempo.ramped());
-
-		XMLNode &after = tmap->get_state();
-		_session->add_command (new Temporal::TempoCommand (_("change tempo type"), &before, &after));
-		commit_reversible_command ();
-
-		TempoMap::update (tmap);
+	TempoMapChange tmc (*this, (tm->tempo().ramped() ? _("set tempo to constant") : _("set tempo to ramped")));;
+	Temporal::TempoPoint const & tempo = tm->tempo();
+	if (!tmc.map().set_ramped (const_cast<Temporal::TempoPoint&>(tempo), !tempo.ramped())) {
+		tmc.abort ();
 	}
 }
 
@@ -1683,24 +1672,12 @@ Editor::toggle_tempo_continues ()
 		return;
 	}
 
-	TempoMap::WritableSharedPtr tmap (TempoMap::write_copy());
-	XMLNode &before = tmap->get_state();
+	TempoMapChange tmc (*this, tm->tempo().continuing() ? _("unclamp tempo from previous") : _("clamp tempo to previous"));
+	Temporal::TempoPoint const & tempo = tm->tempo();
 
-	reassociate_metric_markers (tmap);
-	Temporal::TempoPoint const & tempo (tm->tempo());
-
-	if (!tmap->set_continuing (const_cast<Temporal::TempoPoint&>(tempo), !tempo.continuing())) {
-		abort_tempo_map_edit ();
-		return;
+	if (!tmc.map().set_continuing (const_cast<Temporal::TempoPoint&>(tempo), !tempo.continuing())) {
+		tmc.abort ();
 	}
-
-	begin_reversible_command (_("Change Tempo Continue Behavior"));
-
-	XMLNode &after = tmap->get_state();
-	_session->add_command (new Temporal::TempoCommand (_("change tempo clamp"), &before, &after));
-	commit_reversible_command ();
-
-	TempoMap::update (tmap);
 }
 
 void
@@ -1716,24 +1693,19 @@ Editor::ramp_to_next_tempo ()
 		return;
 	}
 
-	TempoMap::WritableSharedPtr tmap (TempoMap::write_copy());
-	XMLNode &before = tmap->get_state();
+	TempoMapChange tmc (*this, _("set tempo to ramp to next"));
 
-	reassociate_metric_markers (tmap);
 	Temporal::TempoPoint const & tempo (tm->tempo());
 
-	if (!tmap->set_ramped (const_cast<Temporal::TempoPoint&>(tempo), !tempo.ramped())) {
-		abort_tempo_map_edit ();
+	if (tempo.ramped()) {
+		tmc.abort ();
 		return;
 	}
 
-	begin_reversible_command (_("ramp to next tempo"));
-
-	XMLNode &after = tmap->get_state();
-	_session->add_command (new Temporal::TempoCommand (_("changed tempo ramp"), &before, &after));
-	commit_reversible_command ();
-
-	TempoMap::update (tmap);
+	if (!tmc.map().set_ramped (const_cast<Temporal::TempoPoint&>(tempo), true)) {
+		tmc.abort ();
+	}
+	std::cerr << "leave scope\n";
 }
 
 void
