@@ -205,7 +205,7 @@ Editor::select_all_visible_lanes ()
  *  tracks, in which case nothing will happen unless `force' is true.
  */
 void
-Editor::set_selected_track_as_side_effect (Selection::Operation op)
+Editor::set_selected_track_as_side_effect (Selection::Operation op, Controllable::GroupControlDisposition gcd)
 {
 	if (!clicked_axisview) {
 		return;
@@ -223,7 +223,7 @@ Editor::set_selected_track_as_side_effect (Selection::Operation op)
 		if (selection->selected (clicked_axisview)) {
 			if (group && group->is_active() && group->enabled_property(ARDOUR::Properties::group_select.property_id)) {
 				for (TrackViewList::iterator i = track_views.begin(); i != track_views.end (); ++i) {
-					if ((*i)->route_group() == group) {
+					if ((*i)->route_group() == group && gcd != Controllable::NoGroup) {
 						selection->remove(*i);
 					}
 				}
@@ -233,7 +233,7 @@ Editor::set_selected_track_as_side_effect (Selection::Operation op)
 		} else {
 			if (group && group->is_active() && group->enabled_property(ARDOUR::Properties::group_select.property_id)) {
 				for (TrackViewList::iterator i = track_views.begin(); i != track_views.end (); ++i) {
-					if ((*i)->route_group() == group) {
+					if ((*i)->route_group() == group && gcd != Controllable::NoGroup) {
 						selection->add(*i);
 					}
 				}
@@ -246,7 +246,7 @@ Editor::set_selected_track_as_side_effect (Selection::Operation op)
 	case Selection::Add:
 		if (group && group->is_active() && group->enabled_property(ARDOUR::Properties::group_select.property_id)) {
 			for (TrackViewList::iterator i  = track_views.begin(); i != track_views.end (); ++i) {
-				if ((*i)->route_group() == group) {
+				if ((*i)->route_group() == group && gcd != Controllable::NoGroup) {
 					selection->add(*i);
 				}
 			}
@@ -259,7 +259,7 @@ Editor::set_selected_track_as_side_effect (Selection::Operation op)
 		selection->clear();
 		if (group && group->is_active() && group->enabled_property(ARDOUR::Properties::group_select.property_id)) {
 			for (TrackViewList::iterator i  = track_views.begin(); i != track_views.end (); ++i) {
-				if ((*i)->route_group() == group) {
+				if ((*i)->route_group() == group && gcd != Controllable::NoGroup) {
 					selection->add(*i);
 				}
 			}
@@ -537,6 +537,43 @@ Editor::mapover_tracks_with_unique_playlists (sigc::slot<void, RouteTimeAxisView
 	}
 }
 
+void
+Editor::mapover_all_tracks_with_unique_playlists (sigc::slot<void, RouteTimeAxisView&, uint32_t> sl) const
+{
+	set<boost::shared_ptr<Playlist> > playlists;
+
+	set<RouteTimeAxisView*> tracks;
+
+	for (TrackViewList::const_iterator i = track_views.begin(); i != track_views.end(); ++i) {
+		RouteTimeAxisView* v = dynamic_cast<RouteTimeAxisView*> (*i);
+
+		if (!v) {
+			/* Ignore VCAs */
+			continue;
+		}
+
+		boost::shared_ptr<Track> t = v->track();
+		if (t) {
+			if (playlists.insert (t->playlist()).second) {
+				/* haven't seen this playlist yet */
+				tracks.insert (v);
+			}
+		} else {
+			/* not actually a "Track", but a timeaxis view that
+			   we should mapover anyway.
+			*/
+			tracks.insert (v);
+		}
+	}
+
+	/* call the slots */
+	uint32_t const sz = tracks.size ();
+
+	for (set<RouteTimeAxisView*>::iterator i = tracks.begin(); i != tracks.end(); ++i) {
+		sl (**i, sz);
+	}
+}
+
 void
 Editor::mapped_get_equivalent_regions (RouteTimeAxisView& tv, uint32_t, RegionView * basis, vector<RegionView*>* all_equivs) const
 {
@@ -576,6 +613,16 @@ Editor::get_equivalent_regions (RegionView* basis, vector<RegionView*>& equivale
 	equivalent_regions.push_back (basis);
 }
 
+void
+Editor::get_all_equivalent_regions (RegionView* basis, vector<RegionView*>& equivalent_regions) const
+{
+	mapover_all_tracks_with_unique_playlists (sigc::bind (sigc::mem_fun (*this, &Editor::mapped_get_equivalent_regions), basis, &equivalent_regions));
+
+	/* add clicked regionview since we skipped all other regions in the same track as the one it was in */
+
+	equivalent_regions.push_back (basis);
+}
+
 RegionSelection
 Editor::get_equivalent_regions (RegionSelection & basis, PBD::PropertyID prop) const
 {
@@ -629,9 +676,18 @@ Editor::set_selected_regionview_from_click (bool press, Selection::Operation op)
 				} else {
 					if (button_release_can_deselect) {
 
-						/* just remove this one region, but only on a permitted button release */
+						/* just remove this one region
+						 * (or all equivalent regions
+						 * for RippleAll, but only on a
+						 * permitted button release
+						 */
 
-						selection->remove (clicked_regionview);
+						if (should_ripple_all()) {
+							get_all_equivalent_regions (clicked_regionview, all_equivalent_regions);
+							selection->remove (all_equivalent_regions);
+						} else {
+							selection->remove (clicked_regionview);
+						}
 						commit = true;
 
 						/* no more deselect action on button release till a new press
@@ -646,10 +702,14 @@ Editor::set_selected_regionview_from_click (bool press, Selection::Operation op)
 
 				if (press) {
 
-					if (selection->selected (clicked_routeview)) {
-						get_equivalent_regions (clicked_regionview, all_equivalent_regions, ARDOUR::Properties::group_select.property_id);
+					if (should_ripple_all()) {
+						get_all_equivalent_regions (clicked_regionview, all_equivalent_regions);
 					} else {
-						all_equivalent_regions.push_back (clicked_regionview);
+						if (selection->selected (clicked_routeview)) {
+							get_equivalent_regions (clicked_regionview, all_equivalent_regions, ARDOUR::Properties::group_select.property_id);
+						} else {
+							all_equivalent_regions.push_back (clicked_regionview);
+						}
 					}
 
 					/* add all the equivalent regions, but only on button press */
@@ -665,7 +725,11 @@ Editor::set_selected_regionview_from_click (bool press, Selection::Operation op)
 
 		case Selection::Set:
 			if (!selection->selected (clicked_regionview)) {
-				get_equivalent_regions (clicked_regionview, all_equivalent_regions, ARDOUR::Properties::group_select.property_id);
+				if (should_ripple_all()) {
+					get_all_equivalent_regions (clicked_regionview, all_equivalent_regions);
+				} else {
+					get_equivalent_regions (clicked_regionview, all_equivalent_regions, ARDOUR::Properties::group_select.property_id);
+				}
 				selection->set (all_equivalent_regions);
 				commit = true;
 			} else {
@@ -675,7 +739,11 @@ Editor::set_selected_regionview_from_click (bool press, Selection::Operation op)
 				else {
 					if (selection->regions.size() > 1) {
 						/* collapse region selection down to just this one region (and its equivalents) */
-						get_equivalent_regions(clicked_regionview, all_equivalent_regions, ARDOUR::Properties::group_select.property_id);
+						if (should_ripple_all()) {
+							get_all_equivalent_regions (clicked_regionview, all_equivalent_regions);
+						} else {
+							get_equivalent_regions(clicked_regionview, all_equivalent_regions, ARDOUR::Properties::group_select.property_id);
+						}
 						selection->set(all_equivalent_regions);
 						commit = true;
 					}
@@ -691,24 +759,25 @@ Editor::set_selected_regionview_from_click (bool press, Selection::Operation op)
 	} else if (op == Selection::Extend) {
 
 		list<Selectable*> results;
-		samplepos_t last_sample;
-		samplepos_t first_sample;
+		timepos_t last_pos;
+		timepos_t first_pos;
 		bool same_track = false;
 
 		/* 1. find the last selected regionview in the track that was clicked in */
 
-		last_sample = 0;
-		first_sample = max_samplepos;
+		const Temporal::TimeDomain time_domain = (selection->regions.empty() ? Temporal::AudioTime : selection->regions.front()->region()->position().time_domain());
+		last_pos = timepos_t (time_domain);
+		first_pos = timepos_t::max (time_domain);
 
 		for (RegionSelection::iterator x = selection->regions.begin(); x != selection->regions.end(); ++x) {
 			if (&(*x)->get_time_axis_view() == &clicked_regionview->get_time_axis_view()) {
 
-				if ((*x)->region()->last_sample() > last_sample) {
-					last_sample = (*x)->region()->last_sample();
+				if ((*x)->region()->nt_last() > last_pos) {
+					last_pos = (*x)->region()->nt_last();
 				}
 
-				if ((*x)->region()->first_sample() < first_sample) {
-					first_sample = (*x)->region()->first_sample();
+				if ((*x)->region()->position() < first_pos) {
+					first_pos = (*x)->region()->position();
 				}
 
 				same_track = true;
@@ -719,39 +788,39 @@ Editor::set_selected_regionview_from_click (bool press, Selection::Operation op)
 
 			/* 2. figure out the boundaries for our search for new objects */
 
-			switch (clicked_regionview->region()->coverage (first_sample, last_sample)) {
-			case Evoral::OverlapNone:
-				if (last_sample < clicked_regionview->region()->first_sample()) {
-					first_sample = last_sample;
-					last_sample = clicked_regionview->region()->last_sample();
+			switch (clicked_regionview->region()->coverage (first_pos, last_pos)) {
+			case Temporal::OverlapNone:
+				if (last_pos < clicked_regionview->region()->position()) {
+					first_pos = last_pos;
+					last_pos = clicked_regionview->region()->nt_last();
 				} else {
-					last_sample = first_sample;
-					first_sample = clicked_regionview->region()->first_sample();
+					last_pos = first_pos;
+					first_pos = clicked_regionview->region()->position();
 				}
 				break;
 
-			case Evoral::OverlapExternal:
-				if (last_sample < clicked_regionview->region()->first_sample()) {
-					first_sample = last_sample;
-					last_sample = clicked_regionview->region()->last_sample();
+			case Temporal::OverlapExternal:
+				if (last_pos < clicked_regionview->region()->position()) {
+					first_pos = last_pos;
+					last_pos = clicked_regionview->region()->nt_last();
 				} else {
-					last_sample = first_sample;
-					first_sample = clicked_regionview->region()->first_sample();
+					last_pos = first_pos;
+					first_pos = clicked_regionview->region()->position();
 				}
 				break;
 
-			case Evoral::OverlapInternal:
-				if (last_sample < clicked_regionview->region()->first_sample()) {
-					first_sample = last_sample;
-					last_sample = clicked_regionview->region()->last_sample();
+			case Temporal::OverlapInternal:
+				if (last_pos < clicked_regionview->region()->position()) {
+					first_pos = last_pos;
+					last_pos = clicked_regionview->region()->nt_last();
 				} else {
-					last_sample = first_sample;
-					first_sample = clicked_regionview->region()->first_sample();
+					last_pos = first_pos;
+					first_pos = clicked_regionview->region()->position();
 				}
 				break;
 
-			case Evoral::OverlapStart:
-			case Evoral::OverlapEnd:
+			case Temporal::OverlapStart:
+			case Temporal::OverlapEnd:
 				/* nothing to do except add clicked region to selection, since it
 				   overlaps with the existing selection in this track.
 				*/
@@ -766,15 +835,15 @@ Editor::set_selected_regionview_from_click (bool press, Selection::Operation op)
 			*/
 
 
-			first_sample = clicked_regionview->region()->position();
-			last_sample = clicked_regionview->region()->last_sample();
+			first_pos = clicked_regionview->region()->position();
+			last_pos = clicked_regionview->region()->nt_last();
 
 			for (RegionSelection::iterator i = selection->regions.begin(); i != selection->regions.end(); ++i) {
-				if ((*i)->region()->position() < first_sample) {
-					first_sample = (*i)->region()->position();
+				if ((*i)->region()->position() < first_pos) {
+					first_pos = (*i)->region()->position();
 				}
-				if ((*i)->region()->last_sample() + 1 > last_sample) {
-					last_sample = (*i)->region()->last_sample();
+				if ((*i)->region()->end() > last_pos) {
+					last_pos = (*i)->region()->nt_last();
 				}
 			}
 		}
@@ -783,10 +852,19 @@ Editor::set_selected_regionview_from_click (bool press, Selection::Operation op)
 
 		set<RouteTimeAxisView*> relevant_tracks;
 
-		for (TrackSelection::iterator i = selection->tracks.begin(); i != selection->tracks.end(); ++i) {
-			RouteTimeAxisView* r = dynamic_cast<RouteTimeAxisView*> (*i);
-			if (r) {
-				relevant_tracks.insert (r);
+		if (should_ripple_all()) {
+			for (TrackSelection::iterator i = track_views.begin(); i != track_views.end(); ++i) {
+				RouteTimeAxisView* r = dynamic_cast<RouteTimeAxisView*> (*i);
+				if (r) {
+					relevant_tracks.insert (r);
+				}
+			}
+		} else {
+			for (TrackSelection::iterator i = selection->tracks.begin(); i != selection->tracks.end(); ++i) {
+				RouteTimeAxisView* r = dynamic_cast<RouteTimeAxisView*> (*i);
+				if (r) {
+					relevant_tracks.insert (r);
+				}
 			}
 		}
 
@@ -887,7 +965,7 @@ Editor::set_selected_regionview_from_click (bool press, Selection::Operation op)
 		*/
 
 		for (set<RouteTimeAxisView*>::iterator t = relevant_tracks.begin(); t != relevant_tracks.end(); ++t) {
-			(*t)->get_selectables (first_sample, last_sample, -1.0, -1.0, results);
+			(*t)->get_selectables (first_pos, last_pos, -1.0, -1.0, results);
 		}
 
 		/* 4. convert to a vector of regions */
@@ -1161,16 +1239,15 @@ Editor::presentation_info_changed (PropertyChange const & what_changed)
 		}
 	}
 
-	/* STEP 4: update EditorRoutes treeview */
+	/* STEP 4: update Editor::track_views */
 
 	PropertyChange soh;
 
-	soh.add (Properties::selected);
 	soh.add (Properties::order);
 	soh.add (Properties::hidden);
 
 	if (what_changed.contains (soh)) {
-		_routes->sync_treeview_from_presentation_info (what_changed);
+		queue_redisplay_track_views ();
 	}
 }
 
@@ -1218,7 +1295,7 @@ Editor::time_selection_changed ()
 
 	if (_session && !_drags->active()) {
 		if (selection->time.length() != 0) {
-			_session->set_range_selection (selection->time.start(), selection->time.end_sample());
+			_session->set_range_selection (selection->time.start_time(), selection->time.end_time());
 		} else {
 			_session->clear_range_selection ();
 		}
@@ -1288,7 +1365,7 @@ Editor::sensitize_the_right_region_actions (bool because_canvas_crossing)
 			}
 		} else {
 			RegionSelection at_edit_point;
-			samplepos_t const where = get_preferred_edit_position (Editing::EDIT_IGNORE_NONE, false, !within_track_canvas);
+			timepos_t const where = get_preferred_edit_position (Editing::EDIT_IGNORE_NONE, false, !within_track_canvas);
 			get_regions_at (at_edit_point, where, selection->tracks);
 			if (!at_edit_point.empty()) {
 				have_edit_point = true;
@@ -1384,7 +1461,7 @@ Editor::sensitize_the_right_region_actions (bool because_canvas_crossing)
 			have_video_unlocked = true;
 		}
 
-		if (r->position_lock_style() == MusicTime) {
+		if (r->position_time_domain() == Temporal::BeatTime) {
 			have_position_lock_style_music = true;
 		} else {
 			have_position_lock_style_audio = true;
@@ -1441,14 +1518,10 @@ Editor::sensitize_the_right_region_actions (bool because_canvas_crossing)
 		_region_actions->get_action("show-region-list-editor")->set_sensitive (false);
 		_region_actions->get_action("show-region-properties")->set_sensitive (false);
 		_region_actions->get_action("rename-region")->set_sensitive (false);
-		if (have_audio) {
-			/* XXX need to check whether there is than 1 per
-			   playlist, because otherwise this makes no sense.
-			*/
-			_region_actions->get_action("combine-regions")->set_sensitive (true);
-		} else {
-			_region_actions->get_action("combine-regions")->set_sensitive (false);
-		}
+		/* XXX need to check whether there is than 1 per
+		   playlist, because otherwise this makes no sense.
+		*/
+		_region_actions->get_action("combine-regions")->set_sensitive (true);
 	} else if (rs.size() == 1) {
 		_region_actions->get_action("add-range-markers-from-region")->set_sensitive (false);
 		_region_actions->get_action("close-region-gaps")->set_sensitive (false);
@@ -1467,6 +1540,7 @@ Editor::sensitize_the_right_region_actions (bool because_canvas_crossing)
 		_region_actions->get_action("remove-overlap")->set_sensitive (false);
 		_region_actions->get_action("transform-region")->set_sensitive (false);
 		_region_actions->get_action("fork-region")->set_sensitive (false);
+		_region_actions->get_action("fork-regions-from-unselected")->set_sensitive (false);
 		_region_actions->get_action("insert-patch-change-context")->set_sensitive (false);
 		_region_actions->get_action("insert-patch-change")->set_sensitive (false);
 		_region_actions->get_action("transpose-region")->set_sensitive (false);
@@ -1504,7 +1578,7 @@ Editor::sensitize_the_right_region_actions (bool because_canvas_crossing)
 	}
 
 	if (!have_non_unity_scale_amplitude || !have_audio) {
-		_region_actions->get_action("reset-region-scale-amplitude")->set_sensitive (false);
+		_region_actions->get_action("reset-region-gain")->set_sensitive (false);
 	}
 
 	Glib::RefPtr<ToggleAction> a = Glib::RefPtr<ToggleAction>::cast_dynamic (_region_actions->get_action("toggle-region-lock"));
@@ -1611,7 +1685,7 @@ Editor::region_selection_changed ()
 	assert (_session);
 
 	if (!selection->regions.empty()) {
-		_session->set_object_selection (selection->regions.start(), selection->regions.end_sample());
+		_session->set_object_selection (selection->regions.start_time(), selection->regions.end_time());
 	} else {
 		_session->clear_object_selection ();
 	}
@@ -1638,9 +1712,11 @@ Editor::region_selection_changed ()
 
 		/* if in MouseAudition and there's just 1 region selected
 		 * (i.e. we just clicked on it), leave things as they are
+		 *
+		 * Ditto for TimeFX mode
 		 */
 
-		if (selection->regions.size() > 1 || mouse_mode != Editing::MouseAudition) {
+		if (selection->regions.size() > 1 || (mouse_mode != Editing::MouseAudition && mouse_mode != Editing::MouseTimeFX)) {
 			set_mouse_mode (MouseObject, false);
 		}
 	}
@@ -1665,7 +1741,7 @@ Editor::select_all_in_track (Selection::Operation op)
 
 	begin_reversible_selection_op (X_("Select All in Track"));
 
-	clicked_routeview->get_selectables (0, max_samplepos, 0, DBL_MAX, touched);
+	clicked_routeview->get_selectables (timepos_t(), timepos_t::max (Temporal::AudioTime), 0, DBL_MAX, touched);
 
 	switch (op) {
 	case Selection::Toggle:
@@ -1730,7 +1806,7 @@ Editor::select_all_objects (Selection::Operation op)
 		if ((*iter)->hidden()) {
 			continue;
 		}
-		(*iter)->get_selectables (0, max_samplepos, 0, DBL_MAX, touched);
+		(*iter)->get_selectables (timepos_t(), timepos_t::max (Temporal::AudioTime), 0, DBL_MAX, touched);
 	}
 
 	begin_reversible_selection_op (X_("select all"));
@@ -1820,7 +1896,7 @@ Editor::invert_selection ()
  *  within the region are already selected.
  */
 void
-Editor::select_all_within (samplepos_t start, samplepos_t end, double top, double bot, const TrackViewList& tracklist, Selection::Operation op, bool preserve_if_selected)
+Editor::select_all_within (timepos_t const & start, timepos_t const & end, double top, double bot, const TrackViewList& tracklist, Selection::Operation op, bool preserve_if_selected)
 {
 	list<Selectable*> found;
 
@@ -1889,7 +1965,7 @@ Editor::set_selection_from_region ()
 
 	/* select range (this will clear the region selection) */
 
-	selection->set (selection->regions.start(), selection->regions.end_sample());
+	selection->set (selection->regions.start_time(), selection->regions.end_time());
 
 	/* and select the tracks */
 
@@ -1952,10 +2028,12 @@ Editor::select_all_selectables_using_time_selection ()
 		return;
 	}
 
-	samplepos_t start = selection->time[clicked_selection].start;
-	samplepos_t end = selection->time[clicked_selection].end;
+	timepos_t start = selection->time[clicked_selection].start();
+	timepos_t end = selection->time[clicked_selection].end();
 
-	if (end - start < 1)  {
+	const timecnt_t distance = start.distance (end);
+
+	if (distance.is_negative () || distance.is_zero ())  {
 		return;
 	}
 
@@ -1971,7 +2049,7 @@ Editor::select_all_selectables_using_time_selection ()
 		if ((*iter)->hidden()) {
 			continue;
 		}
-		(*iter)->get_selectables (start, end - 1, 0, DBL_MAX, touched);
+		(*iter)->get_selectables (start, end, 0, DBL_MAX, touched);
 	}
 
 	begin_reversible_selection_op (X_("select all from range"));
@@ -1986,7 +2064,7 @@ Editor::select_all_selectables_using_punch()
 	Location* location = _session->locations()->auto_punch_location();
 	list<Selectable *> touched;
 
-	if (location == 0 || (location->end() - location->start() <= 1))  {
+	if (location == 0 || (location->length_samples() <= 1)) {
 		return;
 	}
 
@@ -2003,7 +2081,7 @@ Editor::select_all_selectables_using_punch()
 		if ((*iter)->hidden()) {
 			continue;
 		}
-		(*iter)->get_selectables (location->start(), location->end() - 1, 0, DBL_MAX, touched);
+		(*iter)->get_selectables (location->start(), location->end(), 0, DBL_MAX, touched);
 	}
 	begin_reversible_selection_op (X_("select all from punch"));
 	selection->set (touched);
@@ -2017,7 +2095,7 @@ Editor::select_all_selectables_using_loop()
 	Location* location = _session->locations()->auto_loop_location();
 	list<Selectable *> touched;
 
-	if (location == 0 || (location->end() - location->start() <= 1))  {
+	if (location == 0 || (location->length_samples() <= 1)) {
 		return;
 	}
 
@@ -2034,7 +2112,7 @@ Editor::select_all_selectables_using_loop()
 		if ((*iter)->hidden()) {
 			continue;
 		}
-		(*iter)->get_selectables (location->start(), location->end() - 1, 0, DBL_MAX, touched);
+		(*iter)->get_selectables (location->start(), location->end(), 0, DBL_MAX, touched);
 	}
 	begin_reversible_selection_op (X_("select all from loop"));
 	selection->set (touched);
@@ -2045,17 +2123,17 @@ Editor::select_all_selectables_using_loop()
 void
 Editor::select_all_selectables_using_cursor (EditorCursor *cursor, bool after)
 {
-	samplepos_t start;
-	samplepos_t end;
+	timepos_t start;
+	timepos_t end;
 	list<Selectable *> touched;
 
 	if (after) {
-		start = cursor->current_sample();
-		end = _session->current_end_sample();
+		start = timepos_t (cursor->current_sample());
+		end = timepos_t (_session->current_end_sample());
 	} else {
 		if (cursor->current_sample() > 0) {
-			start = 0;
-			end = cursor->current_sample() - 1;
+			start = timepos_t();
+			end = timepos_t (cursor->current_sample() - 1);
 		} else {
 			return;
 		}
@@ -2098,17 +2176,17 @@ Editor::select_all_selectables_using_cursor (EditorCursor *cursor, bool after)
 void
 Editor::select_all_selectables_using_edit (bool after, bool from_context_menu)
 {
-	samplepos_t start;
-	samplepos_t end;
+	timepos_t start;
+	timepos_t end;
 	list<Selectable *> touched;
 
 	if (after) {
 		start = get_preferred_edit_position(EDIT_IGNORE_NONE, from_context_menu);
-		end = _session->current_end_sample();
+		end = timepos_t (_session->current_end_sample());
 	} else {
 		if ((end = get_preferred_edit_position(EDIT_IGNORE_NONE, from_context_menu)) > 1) {
-			start = 0;
-			end -= 1;
+			start = timepos_t ();
+			end = end.decrement();
 		} else {
 			return;
 		}
@@ -2149,8 +2227,8 @@ Editor::select_all_selectables_using_edit (bool after, bool from_context_menu)
 void
 Editor::select_all_selectables_between (bool within)
 {
-	samplepos_t start;
-	samplepos_t end;
+	timepos_t start;
+	timepos_t end;
 	list<Selectable *> touched;
 
 	if (!get_edit_op_range (start, end)) {
@@ -2185,11 +2263,19 @@ Editor::select_all_selectables_between (bool within)
 	commit_reversible_selection_op ();
 }
 
+void
+Editor::get_regionviews_at_or_after (timepos_t const & pos, RegionSelection& regions)
+{
+	for (TrackViewList::iterator iter = track_views.begin(); iter != track_views.end(); ++iter) {
+		(*iter)->get_regionviews_at_or_after (pos, regions);
+	}
+}
+
 void
 Editor::select_range_between ()
 {
-	samplepos_t start;
-	samplepos_t end;
+	timepos_t start;
+	timepos_t end;
 
 	if (!selection->time.empty()) {
 		selection->clear_time ();
@@ -2209,18 +2295,18 @@ Editor::select_range_between ()
 }
 
 bool
-Editor::get_edit_op_range (samplepos_t& start, samplepos_t& end) const
+Editor::get_edit_op_range (timepos_t& start, timepos_t& end) const
 {
 	/* if an explicit range exists, use it */
 
 	if ((mouse_mode == MouseRange || get_smart_mode()) &&  !selection->time.empty()) {
 		/* we know that these are ordered */
-		start = selection->time.start();
-		end = selection->time.end_sample();
+		start = selection->time.start_time();
+		end = selection->time.end_time();
 		return true;
 	} else {
-		start = 0;
-		end = 0;
+		start = timepos_t ();
+		end = timepos_t ();
 		return false;
 	}
 }
@@ -2234,7 +2320,7 @@ Editor::deselect_all ()
 }
 
 long
-Editor::select_range (samplepos_t s, samplepos_t e)
+Editor::select_range (timepos_t const & s, timepos_t const & e)
 {
 	begin_reversible_selection_op (X_("Select Range"));
 	selection->add (clicked_axisview);
@@ -2266,3 +2352,118 @@ Editor::catch_up_on_midi_selection ()
 		selection->set (regions);
 	}
 }
+
+struct ViewStripable {
+	TimeAxisView* tav;
+	boost::shared_ptr<Stripable> stripable;
+
+	ViewStripable (TimeAxisView* t, boost::shared_ptr<Stripable> s)
+		: tav (t), stripable (s) {}
+};
+
+void
+Editor::move_selected_tracks (bool up)
+{
+	TimeAxisView* scroll_to = 0;
+	StripableList sl;
+	_session->get_stripables (sl);
+
+	if (sl.size() < 2) {
+		/* nope */
+		return;
+	}
+
+	sl.sort (Stripable::Sorter());
+
+	std::list<ViewStripable> view_stripables;
+
+	/* build a list that includes time axis view information */
+
+	for (StripableList::const_iterator sli = sl.begin(); sli != sl.end(); ++sli) {
+		TimeAxisView* tv = time_axis_view_from_stripable (*sli);
+		view_stripables.push_back (ViewStripable (tv, *sli));
+	}
+
+	/* for each selected stripable, move it above or below the adjacent
+	 * stripable that has a time-axis view representation here. If there's
+	 * no such representation, then
+	 */
+
+	list<ViewStripable>::iterator unselected_neighbour;
+	list<ViewStripable>::iterator vsi;
+
+	{
+		PresentationInfo::ChangeSuspender cs;
+
+		if (up) {
+			unselected_neighbour = view_stripables.end ();
+			vsi = view_stripables.begin();
+
+			while (vsi != view_stripables.end()) {
+
+				if (vsi->stripable->is_selected()) {
+
+					if (unselected_neighbour != view_stripables.end()) {
+
+						PresentationInfo::order_t unselected_neighbour_order = unselected_neighbour->stripable->presentation_info().order();
+						PresentationInfo::order_t my_order = vsi->stripable->presentation_info().order();
+
+						unselected_neighbour->stripable->set_presentation_order (my_order);
+						vsi->stripable->set_presentation_order (unselected_neighbour_order);
+
+						if (!scroll_to) {
+							scroll_to = vsi->tav;
+						}
+					}
+
+				} else {
+
+					if (vsi->tav) {
+						unselected_neighbour = vsi;
+					}
+
+				}
+
+				++vsi;
+			}
+
+		} else {
+
+			unselected_neighbour = view_stripables.end();
+			vsi = unselected_neighbour;
+
+			do {
+
+				--vsi;
+
+				if (vsi->stripable->is_selected()) {
+
+					if (unselected_neighbour != view_stripables.end()) {
+
+						PresentationInfo::order_t unselected_neighbour_order = unselected_neighbour->stripable->presentation_info().order();
+						PresentationInfo::order_t my_order = vsi->stripable->presentation_info().order();
+
+						unselected_neighbour->stripable->set_presentation_order (my_order);
+						vsi->stripable->set_presentation_order (unselected_neighbour_order);
+
+						if (!scroll_to) {
+							scroll_to = vsi->tav;
+						}
+					}
+
+				} else {
+
+					if (vsi->tav) {
+						unselected_neighbour = vsi;
+					}
+
+				}
+
+			} while (vsi != view_stripables.begin());
+		}
+	}
+
+	if (scroll_to) {
+		ensure_time_axis_view_is_visible (*scroll_to, false);
+	}
+}
