@@ -50,12 +50,14 @@
 #include "canvas/item.h"
 #include "canvas/line_set.h"
 
+#include "automation_streamview.h"
 #include "bbt_marker_dialog.h"
 #include "editor.h"
 #include "marker.h"
 #include "tempo_dialog.h"
 #include "rgb_macros.h"
 #include "gui_thread.h"
+#include "tempo_map_change.h"
 #include "time_axis_view.h"
 #include "grid_lines.h"
 #include "region_view.h"
@@ -403,12 +405,22 @@ Editor::compute_current_bbt_points (Temporal::TempoMapPoints& grid, samplepos_t
 	switch (bbt_ruler_scale) {
 
 	case bbt_show_quarters:
+		tmap->get_grid (grid, max (tmap->superclock_at (lower_beat), (superclock_t) 0), samples_to_superclock (rightmost, sr), 0, 1);
+		break;
 	case bbt_show_eighths:
+		tmap->get_grid (grid, max (tmap->superclock_at (lower_beat), (superclock_t) 0), samples_to_superclock (rightmost, sr), 0, 2);
+		break;
 	case bbt_show_sixteenths:
+		tmap->get_grid (grid, max (tmap->superclock_at (lower_beat), (superclock_t) 0), samples_to_superclock (rightmost, sr), 0, 4);
+		break;
 	case bbt_show_thirtyseconds:
+		tmap->get_grid (grid, max (tmap->superclock_at (lower_beat), (superclock_t) 0), samples_to_superclock (rightmost, sr), 0, 8);
+		break;
 	case bbt_show_sixtyfourths:
+		tmap->get_grid (grid, max (tmap->superclock_at (lower_beat), (superclock_t) 0), samples_to_superclock (rightmost, sr), 0, 16);
+		break;
 	case bbt_show_onetwentyeighths:
-		tmap->get_grid (grid, max (tmap->superclock_at (lower_beat), (superclock_t) 0), samples_to_superclock (rightmost, sr), 0);
+		tmap->get_grid (grid, max (tmap->superclock_at (lower_beat), (superclock_t) 0), samples_to_superclock (rightmost, sr), 0, 32);
 		break;
 
 	case bbt_show_1:
@@ -478,21 +490,8 @@ Editor::mouse_add_new_tempo_event (timepos_t pos)
 	}
 
 	if (pos.beats() > Beats()) {
-
-		begin_reversible_command (_("add tempo mark"));
-
-		TempoMap::WritableSharedPtr map (TempoMap::write_copy());
-
-		XMLNode &before = map->get_state();
-
-		/* add music-locked ramped (?) tempo using the bpm/note type at sample*/
-
-		map->set_tempo (map->tempo_at (pos), pos);
-		XMLNode &after = map->get_state();
-		_session->add_command (new Temporal::TempoCommand (_("add tempo"), &before, &after));
-		commit_reversible_command ();
-
-		TempoMap::update (map);
+		TempoMapChange tmc (*this, _("add tempo mark"));
+		tmc.map().set_tempo (tmc.map().tempo_at (pos), pos);
 	}
 
 	//map.dump (cerr);
@@ -514,7 +513,6 @@ Editor::mouse_add_new_meter_event (timepos_t pos)
 		return;
 	}
 
-	TempoMap::WritableSharedPtr map (TempoMap::write_copy());
 
 	double bpb = meter_dialog.get_bpb ();
 	bpb = max (1.0, bpb); // XXX is this a reasonable limit?
@@ -524,20 +522,20 @@ Editor::mouse_add_new_meter_event (timepos_t pos)
 	Temporal::BBT_Time requested;
 	meter_dialog.get_bbt_time (requested);
 
-	begin_reversible_command (_("add meter mark"));
 
-	XMLNode &before = map->get_state();
+	TempoMapChange tmc (*this, _("add time signature"));
+	pos = timepos_t (tmc.map().quarters_at (requested));
+	tmc.map().set_meter (Meter (bpb, note_type), pos);
+}
 
-	pos = timepos_t (map->quarters_at (requested));
+void
+Editor::add_bbt_marker_at_playhead_cursor ()
+{
+	if (_session == 0) {
+		return;
+	}
 
-	map->set_meter (Meter (bpb, note_type), pos);
-
-	_session->add_command (new Temporal::TempoCommand (_("add time signature"), &before, &map->get_state()));
-	commit_reversible_command ();
-
-	TempoMap::update (map);
-
-	//map.dump (cerr);
+	mouse_add_bbt_marker_event (timepos_t (_session->transport_sample ()));
 }
 
 void
@@ -549,7 +547,7 @@ Editor::mouse_add_bbt_marker_event (timepos_t pos)
 
 	/* position markers must always be positioned using audio time */
 
-	BBTMarkerDialog marker_dialog  (timepos_t (pos.samples()));
+	BBTMarkerDialog marker_dialog  (timepos_t (pos.samples()), BBT_Time ());
 
 	/* run this modally since we are finishing a drag and the drag object
 	 * will be destroyed when we return from here
@@ -571,20 +569,10 @@ Editor::mouse_add_bbt_marker_event (timepos_t pos)
 	bbt = marker_dialog.bbt_value ();
 	name = marker_dialog.name();
 
-	begin_reversible_command (_("add BBT marker"));
-
-	TempoMap::WritableSharedPtr map (TempoMap::write_copy());
-	XMLNode &before = map->get_state();
-
-	map->set_bartime (bbt, marker_dialog.position(), name);
-
-	_session->add_command (new Temporal::TempoCommand (_("add BBT marker"), &before, &map->get_state()));
-	commit_reversible_command ();
-
-	TempoMap::update (map);
+	TempoMapChange tmc (*this, _("add BBT marker"));
+	tmc.map().set_bartime (bbt, marker_dialog.position(), name);
 }
 
-
 void
 Editor::remove_bbt_marker (ArdourCanvas::Item* item)
 {
@@ -646,20 +634,8 @@ Editor::edit_meter_section (Temporal::MeterPoint& section)
 	Temporal::BBT_Time when;
 	meter_dialog.get_bbt_time (when);
 
-	TempoMap::WritableSharedPtr tmap (TempoMap::write_copy());
-
-	reassociate_metric_markers (tmap);
-
-	begin_reversible_command (_("Edit Time Signature"));
-	XMLNode &before = tmap->get_state();
-
-	tmap->set_meter (meter, when);
-
-	XMLNode &after = tmap->get_state();
-	_session->add_command (new Temporal::TempoCommand (_("edit time signature"), &before, &after));
-	commit_reversible_command ();
-
-	TempoMap::update (tmap);
+	TempoMapChange tmc (*this, _("edit time signature"));
+	tmc.map().set_meter (meter, when);
 }
 
 void
@@ -682,20 +658,9 @@ Editor::edit_bbt (MusicTimePoint& point)
 		return;
 	}
 
-	TempoMap::WritableSharedPtr tmap (TempoMap::write_copy());
-	reassociate_metric_markers (tmap);
-
-	begin_reversible_command (_("Edit Tempo"));
-	XMLNode &before = tmap->get_state();
-
-	tmap->remove_bartime (point);
-	tmap->set_bartime (dialog.bbt_value(), dialog.position(), dialog.name());
-
-	XMLNode &after = tmap->get_state();
-	_session->add_command (new Temporal::TempoCommand (_("edit tempo"), &before, &after));
-	commit_reversible_command ();
-
-	TempoMap::update (tmap);
+	TempoMapChange tmc (*this, _("edit tempo"));
+	tmc.map().remove_bartime (point);
+	tmc.map().set_bartime (dialog.bbt_value(), dialog.position(), dialog.name());
 }
 
 void
@@ -717,22 +682,11 @@ Editor::edit_tempo_section (TempoPoint& section)
 
 	const Tempo tempo (bpm, end_bpm, nt);
 
-	TempoMap::WritableSharedPtr tmap (TempoMap::write_copy());
-	reassociate_metric_markers (tmap);
-
 	Temporal::BBT_Time when;
 	tempo_dialog.get_bbt_time (when);
 
-	begin_reversible_command (_("Edit Tempo"));
-	XMLNode &before = tmap->get_state();
-
-	tmap->set_tempo (tempo, when);
-
-	XMLNode &after = tmap->get_state();
-	_session->add_command (new Temporal::TempoCommand (_("edit tempo"), &before, &after));
-	commit_reversible_command ();
-
-	TempoMap::update (tmap);
+	TempoMapChange tmc (*this, _("edit tempo"));
+	tmc.map().set_tempo (tempo, when);
 }
 
 void
@@ -756,32 +710,16 @@ Editor::edit_bbt_marker (BBTMarker& bm)
 gint
 Editor::real_remove_bbt_marker (MusicTimePoint const * point)
 {
-	begin_reversible_command (_("remove BBT marker"));
-	TempoMap::WritableSharedPtr tmap (TempoMap::write_copy());
-	XMLNode &before = tmap->get_state();
-	tmap->remove_bartime (*point);
-	XMLNode &after = tmap->get_state();
-	_session->add_command (new Temporal::TempoCommand (_("remove BBT marker"), &before, &after));
-	commit_reversible_command ();
-
-	TempoMap::update (tmap);
-
+	TempoMapChange tmc (*this, _("remove BBT marker"));
+	tmc.map().remove_bartime (*point);
 	return FALSE;
 }
 
 gint
 Editor::real_remove_tempo_marker (TempoPoint const * section)
 {
-	begin_reversible_command (_("remove tempo mark"));
-	TempoMap::WritableSharedPtr tmap (TempoMap::write_copy());
-	XMLNode &before = tmap->get_state();
-	tmap->remove_tempo (*section);
-	XMLNode &after = tmap->get_state();
-	_session->add_command (new Temporal::TempoCommand (_("remove tempo change"), &before, &after));
-	commit_reversible_command ();
-
-	TempoMap::update (tmap);
-
+	TempoMapChange tmc (*this, _("remove tempo change"));
+	tmc.map().remove_tempo (*section);
 	return FALSE;
 }
 
@@ -809,16 +747,8 @@ Editor::remove_meter_marker (ArdourCanvas::Item* item)
 gint
 Editor::real_remove_meter_marker (Temporal::MeterPoint const * section)
 {
-	begin_reversible_command (_("remove tempo mark"));
-	TempoMap::WritableSharedPtr tmap (TempoMap::write_copy());
-	XMLNode &before = tmap->get_state();
-	tmap->remove_meter (*section);
-	XMLNode &after = tmap->get_state();
-	_session->add_command (new Temporal::TempoCommand (_("remove time signature change"), &before, &after));
-	commit_reversible_command ();
-
-	TempoMap::update (tmap);
-
+	TempoMapChange tmc (*this, _("remove tempo mark"));
+	tmc.map().remove_meter (*section);
 	return FALSE;
 }
 
@@ -844,7 +774,7 @@ Editor::abort_tempo_map_edit ()
 }
 
 void
-Editor::commit_tempo_map_edit (TempoMap::WritableSharedPtr& new_map, bool with_update)
+Editor::_commit_tempo_map_edit (TempoMap::WritableSharedPtr& new_map, bool with_update)
 {
 	if (!with_update) {
 		PBD::Unwinder<bool> uw (ignore_map_change, true);
@@ -899,21 +829,32 @@ Editor::mid_tempo_per_track_update (TimeAxisView& tav)
 {
 	MidiTimeAxisView* mtav = dynamic_cast<MidiTimeAxisView*> (&tav);
 
-	if (!mtav) {
-		return;
+	if (mtav) {
+		MidiStreamView* msv = mtav->midi_view();
+
+		if (msv) {
+			msv->foreach_regionview (sigc::mem_fun (*this, &Editor::mid_tempo_per_region_update));
+		}
+
+		TimeAxisView::Children kids (tav.get_child_list());
+
+		for (TimeAxisView::Children::iterator ct = kids.begin(); ct != kids.end(); ++ct) {
+
+			boost::shared_ptr<AutomationTimeAxisView> atav = boost::dynamic_pointer_cast<AutomationTimeAxisView> (*ct);
+
+			if (atav) {
+				AutomationStreamView* asv = atav->automation_view ();
+
+				if (asv) {
+					asv->foreach_regionview (sigc::mem_fun (*this, &Editor::mid_tempo_per_region_update));
+				}
+			}
+		}
 	}
-
-	MidiStreamView* msv = mtav->midi_view();
-
-	if (!msv) {
-		return;
-	}
-
-	msv->foreach_regionview (sigc::mem_fun (*this, &Editor::mid_tempo_per_region_update));
 }
 
 void
 Editor::mid_tempo_per_region_update (RegionView* rv)
 {
-	rv->redisplay (true);
+	rv->tempo_map_changed ();
 }
