@@ -260,6 +260,9 @@ PluginPinWidget::PluginPinWidget (boost::shared_ptr<ARDOUR::PluginInsert> pi)
 	AudioEngine::instance ()->PortConnectedOrDisconnected.connect (
 			_io_connection, invalidator (*this), boost::bind (&PluginPinWidget::port_connected_or_disconnected, this, _1, _3), gui_context ()
 			);
+	AudioEngine::instance ()->PortPrettyNameChanged.connect (
+			_io_connection, invalidator (*this), boost::bind (&PluginPinWidget::port_pretty_name_changed, this, _1), gui_context ()
+			);
 }
 
 PluginPinWidget::~PluginPinWidget ()
@@ -505,7 +508,7 @@ PluginPinWidget::refill_output_presets ()
 
 	PluginOutputConfiguration ppc (_pi->plugin (0)->possible_output ());
 	if (ppc.find (0) != ppc.end ()) {
-		// anyting goes
+		// anything goes
 		ppc.clear ();
 		if (n_audio != 0) {
 			ppc.insert (n_audio);
@@ -542,8 +545,8 @@ PluginPinWidget::refill_output_presets ()
 std::string
 PluginPinWidget::port_label (const std::string& portname, bool strip)
 {
-	// compare to MixerStrip::update_io_button()
-	string lpn (PROGRAM_NAME);
+	// compare to IOButton::update
+	string lpn (AudioEngine::instance()->my_name());
 	boost::to_lower (lpn);
 	std::string program_port_prefix = lpn + ":"; // e.g. "ardour:"
 
@@ -1580,7 +1583,7 @@ PluginPinWidget::connect_sidechain ()
 		_sidechain_selector = new IOSelectorWindow (_session, _pi->sidechain_input ());
 	}
 
-	if (_sidechain_selector->is_visible ()) {
+	if (_sidechain_selector->get_visible ()) {
 		_sidechain_selector->get_toplevel ()->get_window ()->raise ();
 	} else {
 		_sidechain_selector->present ();
@@ -1633,9 +1636,22 @@ PluginPinWidget::add_remove_port_clicked (bool add, ARDOUR::DataType dt)
 	ChanCount out = _out;
 	ChanCount sinks = _sinks;
 	assert (add || out.get (dt) > 0);
+	uint32_t n_before = std::min (out.get (dt), _sources.get (dt) * _n_plugins);
 	out.set (dt, out.get (dt) + (add ? 1 : -1));
 	if (!_route ()->customize_plugin_insert (_pi, _n_plugins, out, sinks)) {
 		error_message_dialog (_("Failed to alter plugin output configuration."));
+	} else if (add && dt == DataType::AUDIO) {
+		ChanCount ins, outs, src;
+		_pi->configured_io (ins, outs);
+		src = _pi->natural_output_streams ();
+		for (uint32_t i = n_before; i < outs.get (dt); ++i) {
+			uint32_t pc = i / src.get (dt);
+			uint32_t pn = i % src.get (dt);
+			assert (pc <= _n_plugins);
+			ChanMapping map (_pi->output_map (pc));
+			map.set (dt, pn, pn);
+			_pi->set_output_map (pc, map);
+		}
 	}
 }
 
@@ -1740,7 +1756,6 @@ PluginPinWidget::add_send_from (boost::weak_ptr<ARDOUR::Port> wp, boost::weak_pt
 		return;
 	}
 
-	boost::shared_ptr<Pannable> sendpan (new Pannable (*_session));
 	boost::shared_ptr<Send> send (new Send (*_session, r->pannable (), r->mute_master ()));
 	const ChanCount& outs (r->amp ()->input_streams ());
 	try {
@@ -1823,12 +1838,20 @@ PluginPinWidget::sc_input_press (GdkEventButton *ev, boost::weak_ptr<ARDOUR::Por
 		}
 #endif
 
-		RouteList copy = _session->get_routelist ();
-		copy.sort (Stripable::Sorter(true));
 		uint32_t added = 0;
-		for (ARDOUR::RouteList::const_iterator i = copy.begin (); i != copy.end (); ++i) {
-			added += maybe_add_route_to_input_menu (*i, p->type (), wp);
+
+		if (p) {
+			RouteList copy = _session->get_routelist ();
+			copy.sort (Stripable::Sorter (true));
+			for (ARDOUR::RouteList::const_iterator i = copy.begin (); i != copy.end (); ++i) {
+				added += maybe_add_route_to_input_menu (*i, p->type (), wp);
+			}
 		}
+#if 0
+		else {
+			queue_idle_update ():
+		}
+#endif
 
 		if (added > 0) {
 			citems.push_back (SeparatorElem ());
@@ -1848,7 +1871,8 @@ PluginPinWidget::maybe_add_route_to_input_menu (boost::shared_ptr<Route> r, Data
 		return added;
 	}
 
-	if (_route ()->feeds_according_to_graph (r)) {
+	if (_route ()->feeds (r)) {
+		/* do not allow connfeedback */
 		return added;
 	}
 
@@ -1898,6 +1922,15 @@ PluginPinWidget::port_connected_or_disconnected (boost::weak_ptr<ARDOUR::Port> w
 	}
 }
 
+void
+PluginPinWidget::port_pretty_name_changed (std::string pn)
+{
+	boost::shared_ptr<IO> io = _pi->sidechain_input ();
+	if (io && io->connected_to (pn)) {
+		queue_idle_update ();
+	}
+}
+
 /* lifted from ProcessorEntry::Control */
 PluginPinWidget::Control::Control (boost::shared_ptr<AutomationControl> c, string const & n)
 	: _control (c)
