@@ -391,6 +391,8 @@ RegionView::hide_silent_frames ()
 void
 RegionView::drop_silent_frames ()
 {
+	ItemChangeBlocker cb (*group);
+
 	for (auto& _silent_frame : _silent_frames) {
 		delete _silent_frame;
 	}
@@ -444,6 +446,9 @@ RegionView::region_changed (const PropertyChange& what_changed)
 	if (what_changed.contains (ARDOUR::Properties::time_domain)) {
 		region_renamed ();
 	}
+	if (what_changed.contains (ARDOUR::Properties::length)) {
+		region_renamed ();
+	}
 	if (what_changed.contains (ARDOUR::Properties::sync_position)) {
 		region_sync_changed ();
 	}
@@ -740,21 +745,6 @@ RegionView::set_sync_mark_color ()
 	}
 }
 
-uint32_t
-RegionView::get_fill_color () const
-{
-	Gtkmm2ext::Color f = TimeAxisViewItem::get_fill_color();
-	char const *modname;
-
-	if (_region->opaque() && ( !_dragging && !_region->muted () )) {
-		modname = "opaque region base";
-	} else {
-		modname = "transparent region base";
-	}
-
-	return Gtkmm2ext::HSV(f).mod (UIConfiguration::instance().modifier (modname)).color ();
-}
-
 void
 RegionView::show_region_editor ()
 {
@@ -799,11 +789,7 @@ RegionView::make_name () const
 	}
 
 	if (_region->muted()) {
-#ifdef __APPLE__
-		str = string ("!") + str;
-#else
 		str = std::string("\U0001F507") + str; // SPEAKER WITH CANCELLATION STROKE
-#endif
 	}
 
 	return str;
@@ -1160,8 +1146,8 @@ RegionView::move_contents (timecnt_t const & distance)
  *  Used when inverting snap mode logic with key modifiers, or snap distance calculation.
  *  @return Snapped time offset from this region's position.
  */
-timepos_t
-RegionView::snap_region_time_to_region_time (timepos_t const & x, bool ensure_snap) const
+timecnt_t
+RegionView::snap_region_time_to_region_time (timecnt_t const & x, bool ensure_snap) const
 {
 	PublicEditor& editor = trackview.editor();
 	/* x is region relative, convert it to global absolute time */
@@ -1187,12 +1173,6 @@ RegionView::region_relative_distance (timecnt_t const & duration, Temporal::Time
 	return Temporal::TempoMap::use()->convert_duration (duration, _region->position(), domain);
 }
 
-timecnt_t
-RegionView::source_relative_distance (timecnt_t const & duration, Temporal::TimeDomain domain)
-{
-	return Temporal::TempoMap::use()->convert_duration (duration, _region->source_position(), domain);
-}
-
 void
 RegionView::update_visibility ()
 {
