@@ -284,6 +284,22 @@ ARDOUR_UI_UTILS::sanitized_font (std::string const& name)
 	return fd;
 }
 
+Pango::FontDescription
+ARDOUR_UI_UTILS::ardour_font (std::string const& name)
+{
+	Pango::FontDescription fd (name);
+	if (!fd.get_family().empty() && fd.get_family().find ("Mon") != std::string::npos) {
+		/* matches "ArdourMono", "Monaco" */
+		fd.set_family ("ArdourMono");
+	} else {
+		fd.set_family ("ArdourSans");
+	}
+
+	return fd;
+}
+
+
+
 Pango::FontDescription
 ARDOUR_UI_UTILS::get_font_for_style (string widgetname)
 {
@@ -663,6 +679,22 @@ ARDOUR_UI_UTILS::escape_underscores (string const & s)
 	return o;
 }
 
+Gdk::Color
+ARDOUR_UI_UTILS::unique_palette_color (list<Gdk::Color>& used_colors)
+{
+	Gdk::Color newcolor;
+	string cp = UIConfiguration::instance().get_stripable_color_palette ();
+	Gdk::ArrayHandle_Color gc = ColorSelection::palette_from_string (cp);
+	std::vector<Gdk::Color> c (gc);
+	static std::vector<Gdk::Color>::size_type index = 0;
+
+	if (index >= c.size()) {
+		index = 0;
+	}
+
+	return c[index++];
+}
+
 Gdk::Color
 ARDOUR_UI_UTILS::unique_random_color (list<Gdk::Color>& used_colors)
 {
