@@ -170,6 +170,7 @@ enum AutomationType {
 	MonitoringAutomation,
 	BusSendLevel,
 	BusSendEnable,
+	InsertReturnLevel,
 	MainOutVolume,
 
 	/* used only by Controllable Descriptor to access send parameters */
@@ -638,7 +639,7 @@ typedef std::list<boost::weak_ptr  <Route> > WeakRouteList;
 typedef std::list<boost::weak_ptr  <Stripable> > WeakStripableList;
 typedef std::list<boost::shared_ptr<AutomationControl> > ControlList;
 typedef std::list<boost::shared_ptr<SlavableAutomationControl> > SlavableControlList;
-typedef std::set <boost::shared_ptr<AutomationControl> > AutomationControlSet;
+typedef std::set <AutomationType> AutomationTypeSet;
 
 typedef std::list<boost::shared_ptr<VCA> > VCAList;
 
