@@ -30,6 +30,14 @@
 #include "ardour/data_type.h"
 #include "ardour/mode.h"
 
+/* NOTE: when adding types to this file, you must add four functions:
+
+   std::string to_string (T);
+   T string_to (std::string const &);
+   bool to_string (T, std::string &);
+   bool string_to (std::string const &, T&);
+*/
+
 namespace PBD {
 
 DEFINE_ENUM_CONVERT(Timecode::TimecodeFormat)
@@ -40,7 +48,9 @@ DEFINE_ENUM_CONVERT(ARDOUR::HeaderFormat)
 DEFINE_ENUM_CONVERT(ARDOUR::AutoConnectOption)
 DEFINE_ENUM_CONVERT(ARDOUR::TracksAutoNamingRule)
 DEFINE_ENUM_CONVERT(ARDOUR::TrackMode)
+DEFINE_ENUM_CONVERT(ARDOUR::RecordMode)
 DEFINE_ENUM_CONVERT(ARDOUR::EditMode)
+DEFINE_ENUM_CONVERT(ARDOUR::RippleMode)
 DEFINE_ENUM_CONVERT(ARDOUR::MonitorModel)
 DEFINE_ENUM_CONVERT(ARDOUR::AFLPosition)
 DEFINE_ENUM_CONVERT(ARDOUR::PFLPosition)
@@ -51,7 +61,6 @@ DEFINE_ENUM_CONVERT(ARDOUR::SyncSource)
 DEFINE_ENUM_CONVERT(ARDOUR::ShuttleUnits)
 DEFINE_ENUM_CONVERT(ARDOUR::ClockDeltaMode)
 DEFINE_ENUM_CONVERT(ARDOUR::DenormalModel)
-DEFINE_ENUM_CONVERT(ARDOUR::PositionLockStyle)
 DEFINE_ENUM_CONVERT(ARDOUR::FadeShape)
 DEFINE_ENUM_CONVERT(ARDOUR::RegionSelectionAfterSplit)
 DEFINE_ENUM_CONVERT(ARDOUR::RangeSelectionAfterSplit)
@@ -70,15 +79,72 @@ DEFINE_ENUM_CONVERT(ARDOUR::RegionEquivalence)
 DEFINE_ENUM_CONVERT(ARDOUR::WaveformScale)
 DEFINE_ENUM_CONVERT(ARDOUR::WaveformShape)
 DEFINE_ENUM_CONVERT(ARDOUR::ScreenSaverMode)
+DEFINE_ENUM_CONVERT(ARDOUR::PluginGUIBehavior)
 DEFINE_ENUM_CONVERT(ARDOUR::VUMeterStandard)
 DEFINE_ENUM_CONVERT(ARDOUR::MeterLineUp)
 DEFINE_ENUM_CONVERT(ARDOUR::InputMeterLayout)
 DEFINE_ENUM_CONVERT(ARDOUR::MidiPortFlags)
 DEFINE_ENUM_CONVERT(ARDOUR::TransportRequestType)
 DEFINE_ENUM_CONVERT(ARDOUR::LoopFadeChoice)
+DEFINE_ENUM_CONVERT(ARDOUR::CueBehavior)
 
 DEFINE_ENUM_CONVERT(MusicalMode::Type)
 
+template <>
+inline std::string to_string (ARDOUR::timepos_t val)
+{
+	return val.str ();
+}
+
+template <>
+inline ARDOUR::timepos_t string_to (std::string const & str)
+{
+	ARDOUR::timepos_t tmp (Temporal::AudioTime); /* domain may be changed */
+	tmp.string_to (str);
+	return tmp;
+}
+
+template <>
+inline bool to_string (ARDOUR::timepos_t val, std::string & str)
+{
+	str = val.str ();
+	return true;
+}
+
+template <>
+inline bool string_to (std::string const & str, ARDOUR::timepos_t & val)
+{
+	return val.string_to (str);
+}
+
+
+template <>
+inline std::string to_string (ARDOUR::timecnt_t val)
+{
+	return val.str ();
+}
+
+template <>
+inline ARDOUR::timecnt_t string_to (std::string const & str)
+{
+	ARDOUR::timecnt_t tmp (Temporal::AudioTime); /* domain may change */
+	tmp.string_to (str);
+	return tmp;
+}
+
+template <>
+inline bool to_string (ARDOUR::timecnt_t val, std::string & str)
+{
+	str = val.str ();
+	return true;
+}
+
+template <>
+inline bool string_to (std::string const & str, ARDOUR::timecnt_t & val)
+{
+	return val.string_to (str);
+}
+
 template <>
 inline bool to_string (ARDOUR::AutoState val, std::string& str)
 {
@@ -107,6 +173,33 @@ inline bool string_to (const std::string& str, ARDOUR::DataType& dt)
 	return true;
 }
 
+template <>
+inline bool to_string (ARDOUR::FollowAction fa, std::string& str)
+{
+	str = fa.to_string();
+	return true;
+}
+
+template <>
+inline bool string_to (const std::string& str, ARDOUR::FollowAction& fa)
+{
+	fa = ARDOUR::FollowAction (str);
+	return true;
+}
+
+template<>
+inline std::string to_string (ARDOUR::FollowAction fa)
+{
+	return fa.to_string ();
+}
+
+template<>
+inline ARDOUR::FollowAction string_to (std::string const & str)
+{
+	return ARDOUR::FollowAction (str);
+}
+
+
 } // namespace PBD
 
 #endif // ARDOUR_TYPES_CONVERT_H
