@@ -292,9 +292,6 @@ AudioEngine::process_callback (pframes_t nframes)
 	Temporal::TempoMap::WritableSharedPtr current_map = Temporal::TempoMap::read ();
 	if (current_map != Temporal::TempoMap::use()) {
 		Temporal::TempoMap::set (current_map);
-		if (_session) {
-			_session->tempo_map_changed ();
-		}
 	}
 
 	/* This is for JACK, where the latency callback arrives in sync with
@@ -1194,7 +1191,7 @@ AudioEngine::client_real_time_priority ()
 	if (!_backend->is_realtime ()) {
 		/* this is only an issue with the Dummy backend.
 		 * - with JACK, we require rt permissions.
-		 * - with ALSA/Pulseaudio this can only happen if rt permissions
+		 * - with ALSA/PulseAudio this can only happen if rt permissions
 		 *   are n/a. Other attempts to get rt will fail likewise.
 		 *
 		 * perhaps:
