@@ -102,6 +102,7 @@
 #include "ardour/audioplaylist.h"
 #include "ardour/audioregion.h"
 #include "ardour/buffer_manager.h"
+#include "ardour/clip_library.h"
 #include "ardour/control_protocol_manager.h"
 #include "ardour/directory_names.h"
 #include "ardour/event_type_map.h"
@@ -126,6 +127,7 @@
 #include "ardour/source_factory.h"
 #include "ardour/transport_fsm.h"
 #include "ardour/transport_master_manager.h"
+#include "ardour/triggerbox.h"
 #include "ardour/uri_map.h"
 
 #include "audiographer/routines.h"
@@ -161,10 +163,13 @@ PBD::Signal3<bool, std::string, std::string, int>  ARDOUR::CopyConfigurationFile
 
 std::map<std::string, bool> ARDOUR::reserved_io_names;
 
+float ARDOUR::ui_scale_factor = 1.0;
+
 static bool have_old_configuration_files = false;
 static bool running_from_gui             = false;
 static int  cpu_dma_latency_fd           = -1;
 
+
 namespace ARDOUR {
 extern void setup_enum_writer ();
 }
@@ -365,7 +370,7 @@ lotsa_files_please ()
 		error << string_compose (_("Could not get system open files limit (%1)"), strerror (errno)) << endmsg;
 	}
 #else
-	/* this only affects stdio. 2048 is the maxium possible (512 the default).
+	/* this only affects stdio. 2048 is the maximum possible (512 the default).
 	 *
 	 * If we want more, we'll have to replaces the POSIX I/O interfaces with
 	 * Win32 API calls (CreateFile, WriteFile, etc) which allows for 16K.
@@ -539,6 +544,8 @@ ARDOUR::init (bool try_optimization, const char* localedir, bool with_gui)
 	if (!PBD::init ())
 		return false;
 
+	Temporal::init ();
+
 #if ENABLE_NLS
 	(void)bindtextdomain (PACKAGE, localedir);
 	(void)bind_textdomain_codeset (PACKAGE, "UTF-8");
@@ -546,17 +553,18 @@ ARDOUR::init (bool try_optimization, const char* localedir, bool with_gui)
 
 	SessionEvent::init_event_pool ();
 	TransportFSM::Event::init_pool ();
+	TriggerBox::init ();
 
 	Operations::make_operations_quarks ();
 	SessionObject::make_property_quarks ();
 	Region::make_property_quarks ();
-	MidiRegion::make_property_quarks ();
 	AudioRegion::make_property_quarks ();
 	RouteGroup::make_property_quarks ();
 	Playlist::make_property_quarks ();
 	AudioPlaylist::make_property_quarks ();
 	PresentationInfo::make_property_quarks ();
 	TransportMaster::make_property_quarks ();
+	Trigger::make_property_quarks ();
 
 	/* this is a useful ready to use PropertyChange that many
 	   things need to check. This avoids having to compose
@@ -565,7 +573,6 @@ ARDOUR::init (bool try_optimization, const char* localedir, bool with_gui)
 	*/
 
 	bounds_change.add (ARDOUR::Properties::start);
-	bounds_change.add (ARDOUR::Properties::position);
 	bounds_change.add (ARDOUR::Properties::length);
 
 	/* provide a state version for the few cases that need it and are not
@@ -606,12 +613,17 @@ ARDOUR::init (bool try_optimization, const char* localedir, bool with_gui)
 	}
 #endif
 
+	Port::setup_resampler (Config->get_port_resampler_quality ());
+
 	setup_hardware_optimization (try_optimization);
 
 	if (Config->get_cpu_dma_latency () >= 0) {
 		request_dma_latency ();
 	}
 
+	/* expand `@default@' clip-library-dir config */
+	clip_library_dir (false);
+
 	SourceFactory::init ();
 	Analyser::init ();
 
@@ -636,10 +648,14 @@ ARDOUR::init (bool try_optimization, const char* localedir, bool with_gui)
 	*/
 	EventLoop::register_request_buffer_factory (X_("midiUI"), MidiControlUI::request_factory);
 
-	/* the + 4 is a bit of a handwave. i don't actually know
-	   how many more per-thread buffer sets we need above
-	   the h/w concurrency, but its definitely > 1 more.
-	*/
+	/* Every Process Graph thread (up to hardware_concurrency) keeps a buffer.
+	 * The main engine callback uses one (but returns it after use
+	 * each cycle). Session Export uses one, and the GUI requires
+	 * buffers (for plugin-analysis, auditioner updates) but not
+	 * concurrently.
+	 *
+	 * In theory (hw + 3) should be sufficient, let's add one for luck.
+	 */
 	BufferManager::init (hardware_concurrency () + 4);
 
 	PannerManager::instance ().discover_panners ();
@@ -723,6 +739,11 @@ ARDOUR::cleanup ()
 		return;
 	}
 
+	delete TriggerBox::worker;
+
+	Analyser::terminate ();
+	SourceFactory::terminate ();
+
 	release_dma_latency ();
 	config_connection.disconnect ();
 	engine_startup_connection.disconnect ();
@@ -755,6 +776,10 @@ ARDOUR::no_auto_connect ()
 	return getenv ("ARDOUR_NO_AUTOCONNECT") != 0;
 }
 
+void ARDOUR::set_global_ui_scale_factor (float s) {
+	ui_scale_factor = s;
+}
+
 void
 ARDOUR::setup_fpu ()
 {
@@ -914,6 +939,7 @@ ARDOUR::get_available_sync_options ()
 
 	return ret;
 }
+
 /** Return the number of bits per sample for a given sample format.
  *
  * This is closely related to sndfile_data_width() but does NOT
