@@ -583,7 +583,7 @@ Session::deinterlace_midi_region (boost::shared_ptr<MidiRegion> mr)
 		PropertyList plist (mr->properties ());
 		plist.add (Properties::whole_file, true);
 		plist.add (Properties::name, (*x)->name());
-		plist.add (Properties::tags, string_compose ("%1%2%3", _("split-chans)"), mr->tags ().empty() ? "" : " ", mr->tags ()));
+		plist.add (Properties::tags, string_compose ("%1%2%3", _("(split-chans)"), mr->tags ().empty() ? "" : " ", mr->tags ()));
 		boost::shared_ptr<Region> whole = RegionFactory::create (*x, plist);
 
 		/* ... and insert a discrete copy into the playlist*/
@@ -729,6 +729,15 @@ Session::import_files (ImportStatus& status)
 		} else if (smf_reader) { // midi
 			status.doing_what = string_compose(_("Loading MIDI file %1"), *p);
 			write_midi_data_to_new_files (smf_reader.get(), status, newfiles, status.split_midi_channels);
+
+			if (status.import_markers) {
+				smf_reader->load_markers ();
+				for (auto const& m : smf_reader->markers ()) {
+					Temporal::Beats beats = Temporal::Beats::from_double (m.time_pulses / (double) smf_reader->ppqn ());
+					// XXX import to all sources (in case split_midi_channels is set)?
+					newfiles.front()->add_cue_marker (CueMarker (m.text, timepos_t (beats)));
+				}
+			}
 		}
 
 		++status.current;
