@@ -181,7 +181,8 @@ PluginInsert::set_count (uint32_t num)
 
 			if (require_state) {
 				XMLNode& state = _plugins[0]->get_state ();
-				p->set_state (state, Stateful::loading_state_version);
+				p->set_state (state, Stateful::current_state_version);
+				delete &state;
 			}
 
 			if (active ()) {
@@ -735,9 +736,7 @@ PluginInsert::deactivate ()
 	_timing_stats.reset ();
 	Processor::deactivate ();
 
-	for (Plugins::iterator i = _plugins.begin(); i != _plugins.end(); ++i) {
-		(*i)->deactivate ();
-	}
+	/* Plugin::deactivate is called from run() */
 
 	const samplecnt_t l = effective_latency ();
 	if (_plugin_signal_latency != l) {
@@ -1306,7 +1305,14 @@ PluginInsert::run (BufferSet& bufs, samplepos_t start_sample, samplepos_t end_sa
 		_timing_stats.reset ();
 	}
 
-	if (g_atomic_int_compare_and_exchange (&_flush, 1, 0)) {
+	if (_active != _pending_active && !_pending_active) {
+		/* deactivate */
+		for (Plugins::iterator i = _plugins.begin(); i != _plugins.end(); ++i) {
+			(*i)->deactivate ();
+		}
+	}
+
+	if (check_active () && g_atomic_int_compare_and_exchange (&_flush, 1, 0)) {
 		for (Plugins::iterator i = _plugins.begin(); i != _plugins.end(); ++i) {
 			(*i)->flush ();
 		}
@@ -1379,7 +1385,17 @@ PluginInsert::automate_and_run (BufferSet& bufs, samplepos_t start, samplepos_t
 	while (nframes) {
 
 		samplecnt_t cnt = min (timepos_t (start).distance (next_event.when).samples(), (samplecnt_t) nframes);
+
+		/* This may trigger when loopin a range < 1 sample (if that is even possible).
+		 * Or When there is more than 1 automation point on the same sample but at
+		 * different beat-time (which is probably possible, even though music-time has a much
+		 * larger granularity).
+		 */
 		assert (cnt > 0);
+		if (cnt <= 0) {
+			/* prevent endless loops in optimized builds */
+			break;
+		}
 
 		connect_and_run (bufs, start, start + cnt * speed, speed, cnt, offset, true);
 
@@ -1389,7 +1405,16 @@ PluginInsert::automate_and_run (BufferSet& bufs, samplepos_t start, samplepos_t
 
 		map_loop_range (start, end);
 
-		if (!find_next_event (timepos_t (start), timepos_t (end), next_event)) {
+		/* In general we must use `next_event.when` ot search for next events
+		 * in the time-domain of the automation-list. This prevents finding
+		 * the same event again (see 6a55146fdc).
+		 *
+		 * However when looping, we need to rewind to the mapped loop range
+		 * and take min (start, next_event.when).
+		 */
+		timepos_t next = (next_event.when.samples () == start) ? next_event.when : std::min (timepos_t (start), next_event.when);
+
+		if (!find_next_event (next, timepos_t (end), next_event)) {
 			break;
 		}
 	}
