@@ -19,11 +19,13 @@
  */
 
 #include <boost/bind.hpp>
+#include <glibmm/timer.h>
 
 #include "pbd/error.h"
 #include "pbd/compose.h"
 
 #include "ardour/audioengine.h"
+#include "ardour/butler.h"
 #include "ardour/monitor_control.h"
 #include "ardour/route.h"
 #include "ardour/session.h"
@@ -45,6 +47,30 @@ Session::set_controls (boost::shared_ptr<ControlList> cl, double val, Controllab
 		return;
 	}
 
+#if 1
+	/* This is called by the GUI thread, so we can wait if neccessary to prevent
+	 * "POOL OUT OF MEMORY" fatal errors.
+	 *
+	 * This is not a good solution, because if this happens
+	 * event_loop->call_slot() will most likely also fail to queue a request
+	 * to delete the Events. There is likely an additional Changed() signal
+	 * which needds a EventLoop RequestBuffer slot.
+	 *
+	 * Ideally the EventLoop RequestBuffer would be at least twice the size
+	 * of the the SessionEvent Pool, but it isn't, and even then there may
+	 * still be other signals scheduling events...
+	 */
+	if (SessionEvent::pool_available () < 8) {
+		int sleeptm = std::max (40000, engine().usecs_per_cycle ());
+		int timeout = std::max (10, 1000000 / sleeptm);
+		do {
+			Glib::usleep (sleeptm);
+			ARDOUR::GUIIdle ();
+		}
+		while (SessionEvent::pool_available () < 8 && --timeout > 0);
+	}
+#endif
+
 	for (ControlList::iterator ci = cl->begin(); ci != cl->end(); ++ci) {
 		/* as of july 2017 this is a no-op for everything except record enable */
 		(*ci)->pre_realtime_queue_stuff (val, gcd);
@@ -160,7 +186,12 @@ Session::process_rtop (SessionEvent* ev)
 	ev->rt_slot ();
 
 	if (ev->event_loop) {
-		ev->event_loop->call_slot (MISSING_INVALIDATOR, boost::bind (ev->rt_return, ev));
+		if (!ev->event_loop->call_slot (MISSING_INVALIDATOR, boost::bind (ev->rt_return, ev))) {
+			/* The event must be deleted, otherwise the SessionEvent Pool may fill up */
+			if (!butler ()->delegate (boost::bind (ev->rt_return, ev))) {
+				ev->rt_return (ev);
+			}
+		}
 	} else {
 		warning << string_compose ("programming error: %1", X_("Session RT event queued from thread without a UI - cleanup in RT thread!")) << endmsg;
 		ev->rt_return (ev);
