@@ -268,7 +268,7 @@ FaderPort8::periodic ()
 		_timecode = Timecode::timecode_format_time(TC);
 
 		char buf[16];
-		Timecode::BBT_Time BBT = session->tempo_map ().bbt_at_sample (session->transport_sample ());
+		Temporal::BBT_Time BBT = Temporal::TempoMap::fetch()->bbt_at (timepos_t (session->transport_sample ()));
 		snprintf (buf, sizeof (buf),
 				" %02" PRIu32 "|%02" PRIu32 "|%02" PRIu32 "|%02" PRIu32,
 				BBT.bars % 100, BBT.beats %100,
@@ -513,7 +513,7 @@ FaderPort8::midi_input_handler (Glib::IOCondition ioc, boost::weak_ptr<ARDOUR::A
 	}
 
 #ifdef VERBOSE_DEBUG
-	DEBUG_TRACE (DEBUG::FaderPort8, string_compose ("something happend on %1\n", boost::shared_ptr<MIDI::Port>(port)->name()));
+	DEBUG_TRACE (DEBUG::FaderPort8, string_compose ("something happened on %1\n", boost::shared_ptr<MIDI::Port>(port)->name()));
 #endif
 
 	if (ioc & ~IO_IN) {
@@ -760,7 +760,7 @@ FaderPort8::get_button_action (FP8Controls::ButtonId id, bool press)
  * Persistent State
  */
 XMLNode&
-FaderPort8::get_state ()
+FaderPort8::get_state () const
 {
 	DEBUG_TRACE (DEBUG::FaderPort8, "FaderPort8::get_state\n");
 	XMLNode& node (ControlProtocol::get_state());
@@ -1718,7 +1718,7 @@ FaderPort8::select_strip (boost::weak_ptr<Stripable> ws)
 	if (s == first_selected_stripable () && !shift_mod ()) {
 		if (_ctrls.fader_mode () == ModeTrack) {
 			boost::shared_ptr<AutomationControl> ac = s->gain_control ();
-			ac->start_touch (ac->session().transport_sample());
+			ac->start_touch (timepos_t (ac->session().transport_sample()));
 			ac->set_value (ac->normal (), PBD::Controllable::UseGroup);
 		}
 		return;
